OC.L10N.register(
    "spreed",
    {
    "a conversation" : "en samtale",
    "(Duration %s)" : "(Varighet %s)",
    "You attended a call with {user1}" : "Du har tatt del i en samtale med {user1}",
    "_%n guest_::_%n guests_" : ["%n gjest","%n gjester"],
    "You attended a call with {user1} and {user2}" : "Du har tatt del i en samtale med {user1} og {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Du har tatt del i en samtale med {user1}, {user2} og {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Du har tatt del i en samtale med {user1}, {user2}, {user3} og {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Du har tatt del i en samtale med {user1}, {user2}, {user3}, {user4} og {user5}",
    "_%n other_::_%n others_" : ["én annen person","%n andre"],
    "{actor} invited you to {call}" : "{actor} inviterte deg til {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Du ble invitert til et <strong>samtale</strong>, eller fikk et <strong>anrop</strong>",
    "Other activities" : "Andre aktiviteter",
    "Talk" : "Samtale",
    "Guest" : "Gjest",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "## Velkommen til Nextcloud Talk!\nI denne samtalen vil du bli informert om nye funksjoner som er tilgjengelige i Nextcloud Talk.",
    "## New in Talk %s" : "## Nytt i Talk %s",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge og Safari kan nå bli benyttet for å delta i lyd- og videosamtaler",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- En-til-en-samtaler er nå vedvarende og kan ikke gjøres om til gruppesamtaler ved et uhell lenger. Også når en av deltakerne forlater samtalen, slettes ikke samtalen automatisk lenger. Bare hvis begge deltakerne forlater, slettes samtalen fra serveren.",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Du kan nå varsle alle deltakerne ved å legge ut \"@all\" i chatten",
    "- With the \"arrow-up\" key you can repost your last message" : "- Med \"pil opp\"-tasten kan du legge ut siste melding på nytt",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk kan nå ha kommandoer, send \"/help\" som en chatmelding for å se om administratoren har konfigurert noen",
    "- With projects you can create quick links between conversations, files and other items" : "- Med prosjekter kan du opprette hurtigkoblinger mellom samtaler, filer og andre elementer",
    "- You can now mention guests in the chat" : "- Du kan nå nevne gjester i chat'n",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Samtaler kan nå ha en lobby. Dette vil tillate moderatorer å bli med i chatten og ringe allerede for å forberede møtet, mens brukere og gjester må vente.",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Du kan nå svare direkte på meldinger, noe som gir de andre brukerne mer kontekst hva meldingen handler om",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Søk etter samtaler og deltakere vil nå også filtrere eksisterende samtaler, noe som gjør det mye enklere å finne tidligere samtaler",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Du kan nå legge til egendefinerte brukergrupper i samtaler når circles-appen er installert",
    "- Check out the new grid and call view" : "- Ta en titt på det nye rutenettet og anropsvisningen",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Du kan nå laste opp og dra og slippe filer direkte fra enheten din til chatten",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Delte filer åpnes nå direkte i chatvisningen med visningsprogrammene",
    "- You can now search for chats and messages in the unified search in the top bar" : "- Du kan nå søke etter chatter og meldinger i det enhetlige søket i topplinjen",
    "- Spice up your messages with emojis from the emoji picker" : "- Krydre meldingene dine med emojier fra emoji-velgeren",
    "- You can now change your camera and microphone while being in a call" : "- Du kan nå bytte kamera og mikrofon mens du er i en samtale",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- Gi samtalene dine litt kontekst med en beskrivelse og åpne den slik at påloggede brukere kan finne den og bli med selv",
    "- See a read status and send failed messages again" : "- Se en lesestatus og send meldinger som feilet på nytt",
    "- Raise your hand in a call with the R key" : "- Rekk opp hånden i en samtale med R-tasten",
    "- Join the same conversation and call from multiple devices" : "- Bli med i den samme samtalen og ring fra flere enheter",
    "- Send voice messages, share your location or contact details" : "- Send talemeldinger, del posisjonen eller kontaktinformasjonen din",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- Legg til grupper i en samtale, og nye gruppemedlemmer blir automatisk lagt til som deltakere",
    "- A preview of your audio and video is shown before joining a call" : "- En forhåndsvisning av lyd og video vises før du blir med i en samtale",
    "- You can now blur your background in the newly designed call view" : "- Du kan nå gjøre bakgrunnen uskarp i den nydesignede samtalevisningen",
    "- Moderators can now assign general and individual permissions to participants" : "- Moderatorer kan nå tildele generelle og individuelle tillatelser til deltakere",
    "- You can now react to chat messages" : "- Du kan nå reagere på chatmeldinger",
    "- In the sidebar you can now find an overview of the latest shared items" : "- I sidepanelet kan du nå finne en oversikt over de siste delte elementene",
    "- Use a poll to collect the opinions of others or settle on a date" : "- Bruk en meningsmåling til å samle andres meninger eller bli enige om en dato",
    "- Configure an expiration time for chat messages" : "- Konfigurer en utløpstid for chatmeldinger",
    "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- Start samtaler uten å varsle andre i store samtaler. Du kan sende individuelle anropsvarsler når samtalen har startet.",
    "- Send chat messages without notifying the recipients in case it is not urgent" : "- Send chatmeldinger uten å varsle mottakerne i tilfelle det ikke haster",
    "- Emojis can now be autocompleted by typing a \":\"" : "- Emojier kan nå fullføres automatisk ved å skrive en \":\"",
    "- Link various items using the new smart-picker by typing a \"/\"" : "- Koble ulike elementer ved hjelp av den nye smartvelgeren ved å skrive en \"/\"",
    "- Moderators can now create breakout rooms (requires the High-performance backend)" : "- Moderatorer kan nå opprette grupperom (krever serverdelen med høy ytelse)",
    "- Calls can now be recorded (requires the High-performance backend)" : "- Samtaler kan nå tas opp (krever serverdelen med høy ytelse)",
    "- Conversations can now have an avatar or emoji as icon" : "- Samtaler kan nå ha en avatar eller emoji som ikon",
    "- Virtual backgrounds are now available in addition to the blurred background in video calls" : "- Virtuelle bakgrunner er nå tilgjengelige i tillegg til den uskarpe bakgrunnen i videosamtaler",
    "- Reactions are now available during calls" : "- Reaksjoner er nå tilgjengelige under samtaler",
    "- Typing indicators show which users are currently typing a message" : "- Skriveindikatorer viser hvilke brukere som for øyeblikket skriver en melding",
    "- Groups can now be mentioned in chats" : "- Grupper kan nå nevnes i chatter",
    "- Call recordings are automatically transcribed if a transcription provider app is registered" : "- Samtaleopptak blir automatisk transkribert hvis en transkripsjonsleverandør-app er registrert",
    "- Chat messages can be translated if a translation provider app is registered" : "- Chatmeldinger kan oversettes hvis en oversettelsesleverandør-app er registrert",
    "- **Markdown** can now be used in _chat_ messages" : "- **Markdown** kan nå bli brukt i _chat_ meldinger",
    "- Webhooks are now available to implement bots. See the documentation for more information https://nextcloud-talk.readthedocs.io/en/latest/bot-list/" : "- Webhooks er nå tilgjengelige for å implementere roboter. Se dokumentasjonen for mer informasjon https://nextcloud-talk.readthedocs.io/en/latest/bot-list/",
    "- Set a reminder on a chat message to be notified later again" : "- Angi en påminnelse på en chatmelding for å bli varslet senere igjen",
    "- Use the **Note to self** conversation to take notes and share information between your devices" : "- Bruk **Notat til meg selv**-samtalen for å ta notater og dele informasjon mellom enhetene dine",
    "- Captions allow to send a message with a file at the same time" : "- Bildetekster gjør det mulig å sende en melding med en fil samtidig",
    "- Video of the speaker is now visible while sharing the screen and call reactions are animated" : "- Video av taleren er nå synlig mens skjermen deles, og anropsreaksjoner er animerte",
    "- Messages can now be edited by logged-in authors and moderators for 6 hours" : "- Meldinger kan nå redigeres av innloggede forfattere og moderatorer i 6 timer",
    "- Unsent message drafts are now saved in your browser" : "- Utkast til usendte meldinger lagres nå i nettleseren ",
    "- Moderators can now ban accounts and guests to prevent them from rejoining a conversation" : "- Moderatorer kan nå utestenge kontoer og gjester for å hindre dem i å bli med i en samtale igjen",
    "- Upcoming calls from linked calendar events and out-of-office replacements are now shown in conversations" : "- Kommende anrop fra koblede kalenderhendelser og ikke-tilstedeværende erstatninger vises nå i samtaler",
    "_All %n participant_::_All %n participants_" : ["Alle %n deltaker","Alle %n deltakere"],
    "Talk updates ✅" : "Talk oppdateringer ✅",
    "Reaction deleted by author" : "Reaksjon slettet av forfatter",
    "{actor} created the conversation" : "{actor} opprettet samtalen",
    "You created the conversation" : "Du opprettet samtalen",
    "System created the conversation" : "Systemet opprettet samtalen",
    "An administrator created the conversation" : "En administrator opprettet samtalen",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} endret navnet på samtalen fra  \"%1$s\" til \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Du endret navnet på samtalen fra \"%1$s\" til \"%2$s\"",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "En administrator endret navnet på samtalen fra \"%1$s\" til \"%2$s\"",
    "{actor} set the description" : "{actor} angi beskrivelsen",
    "You set the description" : "Du angav beskrivelsen",
    "An administrator set the description" : "En administrator angav beskrivelsen",
    "{actor} removed the description" : "{actor} fjernet beskrivelsen",
    "You removed the description" : "Du fjernet beskrivelsen",
    "An administrator removed the description" : "En administrator fjernet beskrivelsen",
    "You started a silent call" : "Du startet et stille anrop",
    "{actor} started a silent call" : "{actor} startet et stille anrop",
    "You started a call" : "Du startet et anrop",
    "{actor} started a call" : "{actor} startet en samtale",
    "{actor} joined the call" : "{actor} ble med i samtalen",
    "You joined the call" : "Du ble med i samtalen",
    "{actor} left the call" : "{actor} forlot samtalen",
    "You left the call" : "Du forlot samtalen",
    "{actor} unlocked the conversation" : "{actor} låste opp samtalen",
    "You unlocked the conversation" : "Du låste opp samtalen",
    "An administrator unlocked the conversation" : "En administrator låste opp samtalen",
    "{actor} locked the conversation" : "{actor} låste samtalen",
    "You locked the conversation" : "Du låste samtalen",
    "An administrator locked the conversation" : "En administrator låste samtalen",
    "{actor} limited the conversation to the current participants" : "{actor} begrenset samtalen til de nåværende deltakerne",
    "You limited the conversation to the current participants" : "Du begrenset samtalen til de nåværende deltakerne",
    "An administrator limited the conversation to the current participants" : "En administrator begrenset samtalen til de nåværende deltakerne",
    "{actor} opened the conversation to registered users" : "{actor} åpnet samtalen for registrerte brukere",
    "You opened the conversation to registered users" : "Du åpnet samtalen for registrerte brukere",
    "An administrator opened the conversation to registered users" : "En administrator åpnet samtalen for registrerte brukere",
    "{actor} opened the conversation to registered users and users created with the Guests app" : "{actor} åpnet samtalen for registrerte brukere og brukere opprettet med Guests-appen",
    "You opened the conversation to registered users and users created with the Guests app" : "Du åpnet samtalen for registrerte brukere og brukere opprettet med Guests-appen",
    "An administrator opened the conversation to registered users and users created with the Guests app" : "En administrator åpnet samtalen for registrerte brukere og brukere opprettet med Guests-appen",
    "The conversation is now open to everyone" : "Samtalen er nå åpen for alle",
    "{actor} opened the conversation to everyone" : "{actor} åpnet samtalen for alle",
    "You opened the conversation to everyone" : "Du åpnet samtalen for alle",
    "{actor} restricted the conversation to moderators" : "{actor} begrenset samtalen til moderatorer",
    "You restricted the conversation to moderators" : "Du begrenset samtalen til moderatorer",
    "{actor} started breakout rooms" : "{actor} startet grupperom",
    "You started breakout rooms" : "Du startet grupperom",
    "{actor} stopped breakout rooms" : "{actor} stoppet grupperom",
    "You stopped breakout rooms" : "Du stoppet grupperom",
    "{actor} allowed guests" : "{actor} tillot gjester",
    "You allowed guests" : "Du tillot gjester",
    "An administrator allowed guests" : "En administrator tillot gjester",
    "{actor} disallowed guests" : "{actor} nektet gjester",
    "You disallowed guests" : "Du nektet gjester",
    "An administrator disallowed guests" : "En administrator nektet gjester",
    "{actor} set a password" : "{actor} satte et passord",
    "You set a password" : "Du satte et passord",
    "An administrator set a password" : "En administrator satte et passord",
    "{actor} removed the password" : "{actor} fjernet passordet",
    "You removed the password" : "Du fjernet passordet",
    "An administrator removed the password" : "En administrator fjernet passordet",
    "{actor} added {user}" : "{actor} delte med {user}",
    "You joined the conversation" : "Du ble med i samtalen",
    "{actor} joined the conversation" : "{actor} ble med i samtalen",
    "You added {user}" : "Du delte med {user}",
    "{actor} added you" : "{actor} la til deg",
    "An administrator added you" : "En administrator la til deg",
    "An administrator added {user}" : "En administrator delte med {user}",
    "You left the conversation" : "Du forlot samtalen",
    "{actor} left the conversation" : "{actor} forlot samtalen",
    "{actor} removed {user}" : "{actor} fjernet {user}",
    "You removed {user}" : "Du fjernet {user}",
    "{actor} removed you" : "{actor} fjernet deg",
    "An administrator removed you" : "En administrator fjernet deg",
    "An administrator removed {user}" : "En administrator fjernet {user}",
    "{actor} invited {federated_user}" : "{actor} inviterte {federated_user}",
    "You invited {federated_user}" : "Du inviterte {federated_user}",
    "You accepted the invitation" : "Du godtok invitasjonen",
    "{actor} invited you" : "{actor} inviterte deg",
    "An administrator invited you" : "En administrator inviterte deg",
    "An administrator invited {federated_user}" : "En administrator inviterte {federated_user}",
    "{federated_user} accepted the invitation" : "{federated_user} godtok invitasjonen",
    "{actor} removed {federated_user}" : "{actor} fjernet {federated_user}",
    "You removed {federated_user}" : "Du fjernet {federated_user}",
    "You declined the invitation" : "Du avslo invitasjonen",
    "An administrator removed {federated_user}" : "En administrator fjernet {federated_user}",
    "{federated_user} declined the invitation" : "{federated_user} avviste invitasjonen",
    "{actor} added group {group}" : "{actor} la til gruppe {group}",
    "You added group {group}" : "Du la til gruppen {group}",
    "An administrator added group {group}" : "En administrator la til gruppen {group}",
    "{actor} removed group {group}" : "{actor} fjernet gruppen {group}",
    "You removed group {group}" : "Du fjernet gruppen {group}",
    "An administrator removed group {group}" : "En administrator fjernet gruppen {group}",
    "{actor} added team {circle}" : "{actor} la til laget {circle}",
    "You added team {circle}" : "Du la til laget {circle}",
    "An administrator added team {circle}" : "En administrator la til laget {circle}",
    "{actor} removed team {circle}" : "{actor} fjernet laget {circle}",
    "You removed team {circle}" : "Du fjernet laget {circle}",
    "An administrator removed team {circle}" : "En administrator fjernet laget {circle}",
    "{actor} added {phone}" : "{actor} la til {phone}",
    "You added {phone}" : "Du la til {phone}",
    "An administrator added {phone}" : "En administrator la til {phone}",
    "{actor} removed {phone}" : "{actor} fjernet {phone}",
    "You removed {phone}" : "Du fjernet {phone}",
    "An administrator removed {phone}" : "En administrator fjernet {phone}",
    "{actor} promoted {user} to moderator" : "{actor} forfremmet {user} til moderator",
    "You promoted {user} to moderator" : "Du forfremmet {user} til moderator",
    "{actor} promoted you to moderator" : "{actor} forfremmet deg til moderator",
    "An administrator promoted you to moderator" : "En administrator forfremmet deg til moderator",
    "An administrator promoted {user} to moderator" : "En administrator forfremmet {user} til moderator",
    "{actor} demoted {user} from moderator" : "{actor} nedgraderte {user} fra moderator",
    "You demoted {user} from moderator" : "Du nedgraderte {user} fra moderator",
    "{actor} demoted you from moderator" : "{actor} nedgraderte deg fra moderator",
    "An administrator demoted you from moderator" : "En administrator nedgraderte deg fra moderator",
    "An administrator demoted {user} from moderator" : "En administrator nedgraderte {user} fra moderator",
    "{actor} shared a file which is no longer available" : "{actor} delte en fil som ikke lenger er tilgjengelig",
    "You shared a file which is no longer available" : "Du delte en fil som ikke lenger er tilgjengelig",
    "File shares are currently not supported in federated conversations" : "Delte filressurser støttes for øyeblikket ikke i forente diskusjoner",
    "The shared location is malformed" : "Den delte plasseringen er misformet",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} satte opp Matterbridge for å synkronisere denne samtalen med andre chatter",
    "You set up Matterbridge to synchronize this conversation with other chats" : "Du satte opp Matterbridge for å synkronisere denne samtalen med andre chatter",
    "{actor} updated the Matterbridge configuration" : "{actor} oppdaterte konfigurasjonen av Matterbridge",
    "You updated the Matterbridge configuration" : "Du oppdaterte konfigurasjonen av Matterbridge",
    "{actor} removed the Matterbridge configuration" : "{actor} fjernet konfigurasjonen av Matterbridge",
    "You removed the Matterbridge configuration" : "Du fjernet konfigurasjonen av Matterbridge",
    "{actor} started Matterbridge" : "{actor} startet Matterbridge",
    "You started Matterbridge" : "Du startet Matterbridge",
    "{actor} stopped Matterbridge" : "{actor} stoppet Matterbridge",
    "You stopped Matterbridge" : "Du stoppet Matterbridge",
    "{actor} deleted a message" : "{actor} slettet en melding",
    "You deleted a message" : "Du slettet en melding",
    "{actor} edited a message" : "{actor} redigerte en melding",
    "You edited a message" : "Du redigerte en melding",
    "{actor} deleted a reaction" : "{actor} slettet en reaksjon",
    "You deleted a reaction" : "Du slettet en reaksjon",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["Du satte utløpsdatoen for meldingen til %n uke","Du satte utløpsdatoen for meldingen til %n uker"],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["Du satte utløpsdatoen for meldingen til %n dag","Du satte utløpsdatoen for meldingen til %n dager"],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["Du satte utløpsdatoen for meldingen til %n time","Du satte utløpsdatoen for meldingen til %n timer"],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["Du satte utløpsdatoen for meldingen til %n minutt","Du satte utløpsdatoen for meldingen til %n minutter"],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["{actor} satte utløpsdatoen for meldingen til %n uke","{actor} satte utløpsdatoen for meldingen til %n uker"],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["{actor} satte utløpsdatoen for meldingen til %n dag","{actor} satte utløpsdatoen for meldingen til %n dager"],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["{actor} satte utløpsdatoen for meldingen til %n time","{actor} satte utløpsdatoen for meldingen til %n timer"],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["{actor} satte utløpsdatoen for meldingen til %n minutt","{actor} satte utløpsdatoen for meldingen til %n minutter"],
    "{actor} disabled message expiration" : "{actor} deaktiverte utløpsdato for melding",
    "You disabled message expiration" : "Du deaktiverte utløpsdato for melding",
    "{actor} cleared the history of the conversation" : "{actor} tømte samtalens historikk",
    "You cleared the history of the conversation" : "Du tømte samtalens historikk",
    "{actor} set the conversation picture" : "{actor} satte samtalebildet",
    "You set the conversation picture" : "Du satte samtalebildet",
    "{actor} removed the conversation picture" : "{actor} fjernet samtalebildet",
    "You removed the conversation picture" : "Du fjernet samtalebildet",
    "{actor} ended the poll {poll}" : "{actor} avsluttet avstemningen {poll}",
    "You ended the poll {poll}" : "Du avsluttet avstemningen {poll}",
    "{actor} started the video recording" : "{actor} startet videoopptaket",
    "You started the video recording" : "Du startet videoopptaket",
    "{actor} stopped the video recording" : "{actor} stoppet videoopptaket",
    "You stopped the video recording" : "Du stoppet videoopptaket",
    "{actor} started the audio recording" : "{actor} startet lydopptaket",
    "You started the audio recording" : "Du startet lydopptaket",
    "{actor} stopped the audio recording" : "{actor} stoppet lydopptaket",
    "You stopped the audio recording" : "Du stoppet lydopptaket",
    "The recording failed" : "Opptaket feilet",
    "Someone voted on the poll {poll}" : "Noen stemte på avstemningen {poll}",
    "Message deleted by author" : "Melding slettet av forfatteren",
    "Message deleted by {actor}" : "Melding slettet av {actor}",
    "Message deleted by you" : "Melding slettet av deg",
    "Deleted user" : "Slettet bruker",
    "Unknown number" : "Ukjent nummer",
    "Administration" : "Administrasjon",
    "System" : "System",
    "%s (guest)" : "%s (gjest)",
    "Missed call" : "Tapt anrop",
    "Call ended (Duration {duration})" : "Samtale avsluttet (Varighet {duration})",
    "Call was ended, as it reached the maximum call duration (Duration {duration})" : "Samtalen ble avsluttet da den nådde maksimal samtalevarighet (Varighet {duration})",
    "{actor} ended the call (Duration {duration})" : "{actor} avsluttet samtale (Varighet {duration})",
    "_Call with %n guest was ended, as it reached the maximum call duration (Duration {duration})_::_Call with %n guests was ended, as it reached the maximum call duration (Duration {duration})_" : ["Samtalen med %n gjest ble avsluttet da den nådde maksimal samtalevarighet (Varighet {duration})","Samtalen med %n gjester ble avsluttet da den nådde maksimal samtalevarighet (Varighet {duration})"],
    "_Call with %n guest ended (Duration {duration})_::_Call with %n guests ended (Duration {duration})_" : ["Samtale med %n gjest avsluttet (Varighet {duration})","Samtale med %n gjester avsluttet (Varighet {duration})"],
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} avsluttet samtalen med %n gjest (varighet {duration})","{actor} avsluttet samtalen med %n gjester (varighet {duration})"],
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} avsluttet samtalen med {user1} (varighet {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} avsluttet samtalen med {user1} og {user2} (varighet {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} avsluttet samtalen med {user1}, {user2} og {user3} (varighet {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} avsluttet samtalen med {user1}, {user2}, {user3} og {user4} (varighet {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} avsluttet samtalen med {user1}, {user2}, {user3}, {user4} og {user5} (varighet {duration})",
    "Message of {user} in {conversation}" : "Melding om {user} i {conversation}",
    "Message of {user}" : "Melding om {user}",
    "Message of a deleted user in {conversation}" : "Message om en slettet bruker i  {conversation}",
    "Talk conversations" : "Talk-samtaler",
    "Call %s" : "Ring %s",
    "An error occurred. Please contact your administrator." : "Det oppstod en feil, vennligst kontakt administratoren din.",
    "Storage quota exceeded" : "Overskredet lagringskvote",
    "File not found" : "Finner ikke filen",
    "File is not shared, or shared but not with the user" : "Filen er ikke delt, eller delt, men ikke med brukeren",
    "No account available to delete." : "Ingen konto tilgjengelig for sletting.",
    "Poll" : "Avstemning",
    "No image file provided" : "Ingen bildefil angitt",
    "File is too big" : "Filen er for stor",
    "Invalid file provided" : "Ugyldig fil oppgitt",
    "Invalid image" : "Ugyldig bilde",
    "Unknown filetype" : "Ukjent filtype",
    "Talk mentions" : "Talk nevner",
    "More conversations" : "Flere samtaler",
    "Say hi to your friends and colleagues!" : "Si hei til venner og kolleger!",
    "No unread mentions" : "Ingen uleste nevner",
    "Call in progress" : "Samtale pågår",
    "You were mentioned" : "Du ble nevnt",
    "Write to conversation" : "Skrive til samtalen",
    "Writes event information into a conversation of your choice" : "Skriver hendelsesinformasjon til en diskusjon etter eget valg",
    "Conversation invitation" : "Samtale invitasjon",
    "Description" : "Beskrivelse",
    "You can also dial-in via phone with the following details" : "Du kan også ringe via telefon med følgende detaljer",
    "Dial-in information" : "Ringe informasjon",
    "Meeting ID" : "Møte ID",
    "Your PIN" : "Din PIN",
    "Meeting" : "Møte",
    "Password request: %s" : "Forespørsel om passord: %s",
    "Private conversation" : "Privat samtale",
    "Deleted user (%s)" : "Slettet bruker (%s)",
    "Failed to upload call recording" : "Opplasting av samtaleopptak feilet",
    "The recording server failed to upload recording of call {call}. Please reach out to the administration." : "Opptaksserveren kunne ikke laste opp opptak av samtale {call}. Vennligst ta kontakt med administrasjonen.",
    "Share to chat" : "Del til chat",
    "Dismiss notification" : "Ingen varsel",
    "Call recording now available" : "Opptak av samtale er nå tilgjengelig",
    "The recording for the call in {call} was uploaded to {file}." : "Opptaket for samtalen i {call} ble lastet opp til {file}.",
    "Transcript now available" : "Transkripsjon er nå tilgjengelig",
    "The transcript for the call in {call} was uploaded to {file}." : "Transkripsjonen for samtalen i {call} ble lastet opp til {file}.",
    "Failed to transcript call recording" : "Transkript av samtaleopptak feilet",
    "The server failed to transcript the recording at {file} for the call in {call}. Please reach out to the administration." : "Serveren kunne ikke transkribere opptaket i {file} for samtalen i {call}. Vennligst ta kontakt med administrasjonen.",
    "{user1} invited you to join {roomName} on {remoteServer}" : "{user1} inviterte deg å bli med {roomName} på {remoteServer}",
    "Accept" : "Aksepter",
    "Decline" : "Avslå",
    "{user1} invited you to a federated conversation" : "{user1} inviterte deg til en sammenknyttet samtale",
    "New message" : "Ny melding",
    "Reminder" : "Påminnelse",
    "Reminder: You in {call}" : "Påminnelse: du i {call}",
    "Reminder: {user} in {call}" : "Påminnelse: {user} i {call}",
    "Reminder: Deleted user in {call}" : "Påminnelse: Slettet bruker i {call}",
    "Reminder: {guest} (guest) in {call}" : "Påminnelse: {guest} (gjest) i {call}",
    "Reminder: Guest in {call}" : "Påminnelse: gjest i {call}",
    "{user} reacted with {reaction}" : "{user} reagerte med {reaction}",
    "{user} reacted with {reaction} in {call}" : "{user} reagerte med {reaction} i {call}",
    "Deleted user reacted with {reaction} in {call}" : "Slettet bruker reagerte med {reaction} i {call}",
    "{guest} (guest) reacted with {reaction} in {call}" : "{guest} (gjest) reagerte med {reaction} i {call}",
    "Guest reacted with {reaction} in {call}" : "Gjest reagerte med {reaction} i {call}",
    "{user} in {call}" : "{user} i {call}",
    "Deleted user in {call}" : "Slett bruker i {call}",
    "{guest} (guest) in {call}" : "{guest} (gjest) i {call}",
    "Guest in {call}" : "Gjest i {call}",
    "{user} sent you a private message" : "{user} sente deg en privat melding",
    "{user} sent a message in conversation {call}" : "{user} sente en melding i samtalen {call}",
    "A deleted user sent a message in conversation {call}" : "En slettet bruker sende en melding i samtale {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (gjest) sendte en melding i samtale {call}",
    "A guest sent a message in conversation {call}" : "En gjest sendte en melding i samtale {call}",
    "{user} replied to your private message" : "{user} svarte på din private melding",
    "{user} replied to your message in conversation {call}" : "{user} svarte på din melding i samtale {call}",
    "A deleted user replied to your message in conversation {call}" : "En slettet bruker svarte på din melding i samtale {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (gjest) svarte på din melding i samtale {call}",
    "A guest replied to your message in conversation {call}" : "En gjest svarte på din melding i samtale {call}",
    "Reminder: You in private conversation {call}" : "Påminnelse: du i privat samtale {call}",
    "Reminder: A deleted user in private conversation {call}" : "Påminnelse: en slettet bruker i privat samtale {call}",
    "Reminder: {user} in private conversation" : "Påminnelse: {user} i privat samtale",
    "Reminder: You in conversation {call}" : "Påminnelse: du i samtale {call}",
    "Reminder: {user} in conversation {call}" : "Påminnelse: {user} i samtale {call}",
    "Reminder: A deleted user in conversation {call}" : "Påminnelse: en slettet bruker i samtale {call}",
    "Reminder: {guest} (guest) in conversation {call}" : "Påminnelse: {guest} (gjest) i samtale {call}",
    "Reminder: A guest in conversation {call}" : "Påminnelse: en gjest i samtale {call}",
    "{user} reacted with {reaction} to your private message" : "{user} reagerte med {reaction} på din private melding",
    "{user} reacted with {reaction} to your message in conversation {call}" : "{user} reagerte med {reaction} på din melding i samtale {call}",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "En slettet bruker reagerte med {reaction} på din melding i samtale {call}",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "{guest} (gjest) reagerte med {reaction} på din melding i samtale {call}",
    "A guest reacted with {reaction} to your message in conversation {call}" : "En gjest reagerte med {reaction} på din melding i samtale {call}",
    "{user} mentioned you in a private conversation" : "{user} nevnte deg i en privat samtale",
    "{user} mentioned group {group} in conversation {call}" : "{user} nevnte gruppe {group} i samtale {call}",
    "{user} mentioned everyone in conversation {call}" : "{user} nevnte alle i samtale {call}",
    "{user} mentioned you in conversation {call}" : "{user} nevnte deg i samtale {call}",
    "A deleted user mentioned group {group} in conversation {call}" : "En slettet bruker nevnte gruppe {group} i samtale {call}",
    "A deleted user mentioned everyone in conversation {call}" : "En slettet bruker nevnte alle i samtale {call}",
    "A deleted user mentioned you in conversation {call}" : "En slettet bruker nevnte deg i samtale {call}",
    "{guest} (guest) mentioned group {group} in conversation {call}" : "{guest} (gjest) nevnte gruppe {group} i samtale {call}",
    "{guest} (guest) mentioned everyone in conversation {call}" : "{guest} (gjest) nevnte alle i samtale {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (gjest) nevnte deg i samtale {call}",
    "A guest mentioned group {group} in conversation {call}" : "En gjest nevnte gruppe {group} i samtale {call}",
    "A guest mentioned everyone in conversation {call}" : "En gjest nevnte alle i samtale {call}",
    "A guest mentioned you in conversation {call}" : "En gjest nevnte deg i samtale {call}",
    "View message" : "Se melding",
    "Dismiss reminder" : "Avvis påminnelse",
    "View chat" : "Vis samtale",
    "{user} invited you to a group conversation: {call}" : "{user} inviterte deg til en gruppesamtale: {call}",
    "Join call" : "Ta del i samtale",
    "Answer call" : "Svar anrop",
    "{user} would like to talk with you" : "{user} ønsker å snakke med deg",
    "Call back" : "Ring tilbake",
    "You missed a call from {user}" : "Du har et tapt anrop fra {user}",
    "You missed a phone call from {call}" : "Du har et tapt telefonanrop fra {call}",
    "A group call has started in {call}" : "En gruppesamtale har startet i {call}",
    "You missed a group call in {call}" : "Du gikk glipp av en gruppesamtale i {call}",
    "{email} is requesting the password to access {file}" : "{email} ber om passordet for å få tilgang til {file}",
    "{email} tried to request the password to access {file}" : "{email} prøvde å be om passordet for å få tilgang til  {file}",
    "Someone is requesting the password to access {file}" : "Noen ber om passordet for å få tilgang til {file}",
    "Someone tried to request the password to access {file}" : "Noen prøvde å be om passordet for å få tilgang til {file}",
    "Open settings" : "Åpne innstillinger",
    "Hosted signaling server added" : "Vertsbasert signalserver lagt til",
    "The hosted signaling server is now configured and will be used." : "Den vertsbaserte signalserveren er nå konfigurert og vil bli brukt.",
    "Hosted signaling server removed" : "Vertsbasert signalserver fjernet",
    "The hosted signaling server was removed and will not be used anymore." : "Den vertsbaserte signalserveren ble fjernet og vil ikke bli brukt lenger.",
    "Hosted signaling server changed" : "Vertsbasert signalserver endret",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "Den vertsbaserte signalserverkontoen har endret statusen fra \"{oldstatus}\" til \"{newstatus}\".",
    "pending" : "venter",
    "active" : "aktiv",
    "expired" : "utløpt",
    "blocked" : "blokkert",
    "error" : "feil",
    "The certificate of {host} expires in {days} days" : "Sertifikatet til {host} utløper om {days} dager",
    "The certificate of {host} expired" : "Sertifikatet til {host} er utløpt",
    "Contact via Talk" : "Kontakt via Talk",
    "Open Talk" : "Åpne Talk",
    "Default" : "Standard",
    "Presentation" : "Presentasjon",
    "Conversations" : "Samtaler",
    "Messages in current conversation" : "Meldinger i gjeldende samtale",
    "{user}" : "{bruker}",
    "Messages" : "Meldinger",
    "{user} in {conversation}" : "{user} i {conversation}",
    "Messages in other conversations" : "Meldinger i andre samtaler",
    "One-to-one rooms always need to show the other users avatar" : "En-til-en-rom må alltid vise den andre brukerens avatar",
    "Invalid emoji character" : "Ugyldig emoji-karakter",
    "Invalid background color" : "Ugyldig bakgrunnsfarge",
    "Avatar image is not square" : "Avatarbilde er ikke firkantet",
    "Room {number}" : "Rom {number}",
    "Favorites" : "Favoritter",
    "Other" : "Annet",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "Kunne ikke be om prøveversjon fordi prøveserveren ikke er tilgjengelig. Vennligst prøv igjen senere.",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "Det er et problem med autentiseringen av denne forekomsten. Kanskje den ikke er tilgjengelig fra utsiden for å bekrefte dens nettadresse.",
    "Something unexpected happened." : "Noe uventet inntraff.",
    "The URL is invalid." : "Nettadressen er ugyldig.",
    "An HTTPS URL is required." : "En HTTPS URL er påkrevd.",
    "The email address is invalid." : "Epostadressen er ugyldig.",
    "The language is invalid." : "Angitt språk er ugyldig.",
    "The country is invalid." : "Angitt land er ugyldig",
    "There is a problem with the request of the trial. Please check your logs for further information." : "Det er et problem med forespørselen om prøveversjonen. Vennligst sjekk loggene dine for mer informasjon.",
    "Too many requests are send from your servers address. Please try again later." : "For mange forespørsler sendes fra serveradressen din. Vennligst prøv igjen senere.",
    "There is already a trial registered for this Nextcloud instance." : "Det er allerede registrert en prøveversjon for denne Nextcloud-forekomsten.",
    "Something unexpected happened. Please try again later." : "Noe uventet inntraff. Vennligst prøv igjen senere.",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "Kunne ikke be om prøveversjon fordi prøveserveren oppførte seg feil. Vennligst prøv igjen senere.",
    "Trial requested but failed to get account information. Please check back later." : "Prøveversjonen ble bedt om, men fikk ikke kontoinformasjon. Vennligst kom tilbake senere.",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "Det er et problem med autentiseringen av denne forespørselen. Kanskje den ikke er tilgjengelig fra utsiden for å bekrefte dens nettadresse.",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "Kunne ikke hente kontoinformasjon fordi prøveserveren oppførte seg feil. Vennligst kom tilbake senere.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "Det har oppstått et problem med å hente kontoinformasjonen. Vennligst sjekk loggene dine for mer informasjon.",
    "There is no such account registered." : "Det er ingen slik konto registrert.",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "Kan ikke hente kontoinformasjon fordi prøveserveren ikke kan nås. Vennligst kom tilbake senere.",
    "Deleting the hosted signaling server account failed. Please check back later." : "Sletting av den vertsbaserte signalserverkontoen feilet. Vennligst kom tilbake senere.",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "Kunne ikke slette kontoen fordi prøveserveren oppførte seg feil. Vennligst kom tilbake senere.",
    "There is a problem with deleting the account. Please check your logs for further information." : "Det er et problem med å slette kontoen. Vennligst sjekk loggene dine for mer informasjon.",
    "Too many requests are sent from your servers address. Please try again later." : "For mange forespørsler sendes fra serveradressen din. Vennligst prøv igjen senere.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "Kan ikke slette kontoen fordi prøveserveren ikke kan nås. Vennligst kom tilbake senere.",
    "Note to self" : "Notat til meg selv",
    "A place for your private notes, thoughts and ideas" : "Et sted for private notater, tanker og ideer",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "De forente arabiske emirater",
    "Afghanistan" : "Afganistan",
    "Antigua and Barbuda" : "Antigua og Barbuda",
    "Anguilla" : "Angola",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Antarctica" : "Antarktis",
    "Argentina" : "Argentina",
    "American Samoa" : "Amerikansk Samoa",
    "Austria" : "Østerike",
    "Australia" : "Australia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Åland",
    "Azerbaijan" : "Azerbaijan",
    "Bosnia and Herzegovina" : "Bosnia og Hersegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgia",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Bahrain" : "Bahrain",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint-Barthélemy",
    "Bermuda" : "Bermuda",
    "Brunei Darussalam" : "Brunei",
    "Bolivia, Plurinational State of" : "Bolivia",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius og Saba",
    "Brazil" : "Brasil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhutan",
    "Bouvet Island" : "Bouvetøya",
    "Botswana" : "Botswana",
    "Belarus" : "Hviterusland",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Kokosøyene",
    "Congo, the Democratic Republic of the" : "Kongo (den demokratiske republikk)",
    "Central African Republic" : "Den sentralafrikanske republikk",
    "Congo" : "Kongo",
    "Switzerland" : "Sveits",
    "Côte d'Ivoire" : "Elfenbenskysten",
    "Cook Islands" : "Cookøyene",
    "Chile" : "Chile",
    "Cameroon" : "Kameron",
    "China" : "Kina",
    "Colombia" : "Kolombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Kuba",
    "Cabo Verde" : "Kapp Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Christmasøya",
    "Cyprus" : "Kypros",
    "Czechia" : "Tsjekkia",
    "Germany" : "Tyskland",
    "Djibouti" : "Djibouti",
    "Denmark" : "Danmark",
    "Dominica" : "Dominica",
    "Dominican Republic" : "Den dominikanske republikk",
    "Algeria" : "Algeri",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estland",
    "Egypt" : "Egypt",
    "Western Sahara" : "Vest-Sahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Spania",
    "Ethiopia" : "Etiopia",
    "Finland" : "Finland",
    "Fiji" : "Fiji",
    "Falkland Islands (Malvinas)" : "Falklandsøyene (Malvinas)",
    "Micronesia, Federated States of" : "Mikronesiaføderasjonen",
    "Faroe Islands" : "Færøyene",
    "France" : "Frankrike",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "Storbritannia og Nord-Irland",
    "Grenada" : "Grenada",
    "Georgia" : "Georgia",
    "French Guiana" : "Fransk Guiana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Grønland",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Ekvatorial-Guinea",
    "Greece" : "Hellas",
    "South Georgia and the South Sandwich Islands" : "Sør-Georgia og Sør-Sandwichøyene",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Heard- og McDonaldøyene",
    "Honduras" : "Honduras",
    "Croatia" : "Kroatia",
    "Haiti" : "Haiti",
    "Hungary" : "Ungarn",
    "Indonesia" : "Indonesia",
    "Ireland" : "Irland",
    "Israel" : "Israel",
    "Isle of Man" : "Isle of Man",
    "India" : "India",
    "British Indian Ocean Territory" : "Det britiske territoriet i Indiahavet",
    "Iraq" : "Irak",
    "Iran, Islamic Republic of" : "Iran",
    "Iceland" : "Island",
    "Italy" : "Italia",
    "Jersey" : "Jersey",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordan",
    "Japan" : "Japan",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kyrgyzstan",
    "Cambodia" : "Kambodia",
    "Kiribati" : "Kiribati",
    "Comoros" : "Komorene",
    "Saint Kitts and Nevis" : "Saint Kitts og Nevis",
    "Korea, Democratic People's Republic of" : "Den demokratiske folkerepublikken Korea",
    "Korea, Republic of" : "Republikken Korea",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Cayman Islands",
    "Kazakhstan" : "Kazakhstan",
    "Lao People's Democratic Republic" : "Laos",
    "Lebanon" : "Libanon",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Litauen",
    "Luxembourg" : "Luxembourg",
    "Latvia" : "Latvia",
    "Libya" : "Libya",
    "Morocco" : "Marokko",
    "Monaco" : "Monaco",
    "Moldova, Republic of" : "Moldova",
    "Montenegro" : "Montenegro",
    "Saint Martin (French part)" : "Saint Martin (Fransk del)",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Marshalløyene",
    "North Macedonia" : "Nord-Makedonia",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolia",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Nord-Marianene",
    "Martinique" : "Martinique",
    "Mauritania" : "Mauritania",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Maldivene",
    "Malawi" : "Malawi",
    "Mexico" : "Mexico",
    "Malaysia" : "Malaysia",
    "Mozambique" : "Mosambik",
    "Namibia" : "Namibia",
    "New Caledonia" : "Ny-Caledonia",
    "Niger" : "Niger",
    "Norfolk Island" : "Norfolkøya",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Nederland",
    "Norway" : "Norge",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "New Zealand",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Fransk Polynesia",
    "Papua New Guinea" : "Papua Ny-Guinea",
    "Philippines" : "Filipinene",
    "Pakistan" : "Pakistan",
    "Poland" : "Polen",
    "Saint Pierre and Miquelon" : "Saint-Pierre og Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Puerto Rico",
    "Palestine, State of" : "Palestina",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Qatar",
    "Réunion" : "Réunion",
    "Romania" : "Romania",
    "Serbia" : "Serbia",
    "Russian Federation" : "Russland",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Saudi Arabia",
    "Solomon Islands" : "Solomon Islands",
    "Seychelles" : "Seychellene ",
    "Sudan" : "Sudan",
    "Sweden" : "Sverige",
    "Singapore" : "Singapore",
    "Saint Helena, Ascension and Tristan da Cunha" : "Saint Helena, Ascension og Tristan da Cunha",
    "Slovenia" : "Slovenia",
    "Svalbard and Jan Mayen" : "Svalbard og Jan Mayen",
    "Slovakia" : "Slovakia",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Surinam",
    "South Sudan" : "Sør Sudan",
    "Sao Tome and Principe" : "Sao Tome og Principe",
    "El Salvador" : "El Salvador",
    "Sint Maarten (Dutch part)" : "Sint Maarten (Nederlandsk del)",
    "Syrian Arab Republic" : "Syria",
    "Eswatini" : "Eswatini",
    "Turks and Caicos Islands" : "Turks- og Caicosøyene",
    "Chad" : "Chad",
    "French Southern Territories" : "De franske sørterritorier",
    "Togo" : "Togo",
    "Thailand" : "Thailand",
    "Tajikistan" : "Tajikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunis",
    "Tonga" : "Tonga",
    "Turkey" : "Tyrkia",
    "Trinidad and Tobago" : "Trinidad og Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan, Province of China" : "Taiwan",
    "Tanzania, United Republic of" : "Tanzania",
    "Ukraine" : "Ukraina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "USAs ytre småøyer",
    "United States of America" : "USA",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Uzbekistan",
    "Holy See" : "Den hellige stol",
    "Saint Vincent and the Grenadines" : "Saint Vincent og Grenadinene",
    "Venezuela, Bolivarian Republic of" : "Venezuela",
    "Virgin Islands, British" : "Jomfruøyene, engelsk",
    "Virgin Islands, U.S." : "Jomfruøyene, US",
    "Viet Nam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis- og Futunaøyene",
    "Samoa" : "Samoa",
    "Yemen" : "Yemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Sør-Afrika",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Federation" : "Sammenknytting",
    "High-performance backend" : "Backend med høy ytelse",
    "Error: Cannot connect to server" : "Feil: kan ikke koble til server",
    "Error: Server did not respond with proper JSON" : "Feil: serveren svarte ikke med riktig JSON",
    "Error: Certificate expired" : "Feil: sertifikat utløpt",
    "Could not get version" : "Kunne ikke hente versjon",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "Feil: kjørende versjon: {versjon}; serveren må oppdateres for å være kompatibel med denne versjonen av Talk.",
    "Error: Server responded with: {error}" : "Feil: server svarte med: {error}",
    "Error: Unknown error occurred" : "Feil: ukjent feil oppstod",
    "Warning: Running version: {version}; Server does not support all features of this Talk version, missing features: {features}" : "Advarsel: kjørende versjon: {versjon}; server støtter ikke alle funksjonene i denne Talk-versjonen, mangler funksjoner: {funksjoner}.",
    "Recording backend" : "Opptaks-backend",
    "SIP configuration" : "SIP innstillinger",
    "Invalid date, date format must be YYYY-MM-DD" : "Feil dato, dato må være i formatet YYYY-MM-DD",
    "Conversation not found" : "Samtalen ble ikke funnet",
    "Path is already shared with this conversation" : "Stien er allerede delt med denne samtalen",
    "Chat, video & audio-conferencing using WebRTC" : "Chat, video og lydkonferanser ved hjelp av WebRTC",
    "Chat, video & audio-conferencing using WebRTC\n\n* 💬 **Chat** Nextcloud Talk comes with a simple text chat, allowing you to share or upload files from your Nextcloud Files app or local device and mention other participants.\n* 👥 **Private, group, public and password protected calls!** Invite someone, a whole group or send a public link to invite to a call.\n* 🌐 **Federated chats** Chat with other Nextcloud users on their servers\n* 💻 **Screen sharing!** Share your screen with the participants of your call.\n* 🚀 **Integration with other Nextcloud apps** like Files, Calendar, User status, Dashboard, Flow, Maps, Smart picker, Contacts, Deck, and many more.\n* 🌉 **Sync with other chat solutions** With [Matterbridge](https://github.com/42wim/matterbridge/) being integrated in Talk, you can easily sync a lot of other chat solutions to Nextcloud Talk and vice-versa." : "Chat, video og lydkonferanser ved hjelp av WebRTC\n\n* 💬 **Chat** Nextcloud Talk leveres med en enkel tekstchat, slik at du kan dele eller laste opp filer fra Nextcloud Filer-appen eller den lokale enheten og nevne andre deltakere.\n* 👥 **Private, gruppe, offentlige og passordbeskyttede samtaler!** Inviter noen, en hel gruppe eller send en offentlig kobling for å invitere til en samtale.\n* 🌐 **Samlede chatter** Chat med andre Nextcloud-brukere på deres servere\n* 💻 **Skjermdeling!** Del skjermen din med deltakerne i samtalen.\n* 🚀 **Integrasjon med andre Nextcloud-apper** som Filer, Kalender, Brukerstatus, Dashboard, Flyt, Kart, Smart picker, Kontakter, Deck, og mange flere.\n* 🌉 **Synkroniser med andre chat-løsninger** Med [Matterbridge](https://github.com/42wim/matterbridge/) blir integrert i Talk,  du kan enkelt synkronisere mange andre chat-løsninger til Nextcloud Talk og omvendt.",
    "Leave call" : "Forlat samtalen",
    "Navigating away from the page will leave the call in {conversation}" : "Navigering bort fra siden vil forlate samtalen i {conversation}",
    "Stay in call" : "Forbli i samtalen",
    "Duplicate session" : "Dupliser økten",
    "Discuss this file" : "Diskuter denne filen",
    "Loading …" : "Laster ...",
    "Share this file with others to discuss it" : "Del denne filen med andre og diskuter den",
    "Join conversation" : "Delta i samtale",
    "Share this file" : "Del denne filen",
    "Error occurred when joining the conversation" : "Det oppstod en feil da du ble med i samtalen",
    "This conversation is password-protected." : "Denne samtalen er passordbeskyttet",
    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "Vi har oppdaget flere ugyldige passordforsøk fra IP-adressen din. Derfor strupes neste forsøk opptil 30 sekunder.",
    "The password is wrong. Try again." : "Feil passord. Prøv igjen.",
    "Password" : "Passord",
    "Submit" : "Send inn",
    "Error requesting the password." : "Feil ved forespørsel om passordet.",
    "Request password" : "Forespør om passord",
    "This conversation has ended" : "Denne samtalen er avsluttet",
    "Close Talk sidebar" : "Lukk Talk-sidefeltet",
    "Open Talk sidebar" : "Åpne Talk-sidefeltet",
    "Everyone" : "Alle",
    "Users and moderators" : "Brukere og moderatorer",
    "Moderators only" : "Kun moderatorer",
    "Disable calls" : "Deaktiver anrop",
    "Save changes" : "Lagre endringer",
    "Saving …" : "Lagrer...",
    "Saved!" : "Lagret!",
    "Limit to groups" : "Begrens til grupper",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Når minst én gruppe er valgt, kan bare personer i de oppførte gruppene delta i samtaler.",
    "Guests can still join public conversations." : "Gjester kan fortsatt delta i offentlige samtaler.",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Brukere som ikke kan bruke Talk lenger, vil fortsatt bli oppført som deltakere i tidligere samtaler, og chatmeldingene deres vil også bli beholdt.",
    "Limit using Talk" : "Begrens bruk av Talk",
    "Limit creating a public and group conversation" : "Begrens oppretting av en offentlig- og gruppesamtale",
    "Limit creating conversations" : "Begrens oppretting av samtaler",
    "Limit starting a call" : "Begrens å starte et anrop",
    "Limit starting calls" : "Begrens å starte flere anrop",
    "When a call has started, everyone with access to the conversation can join the call." : "Når en samtale har startet, kan alle med tilgang til samtalen bli med i samtalen.",
    "The following bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Følgende roboter er installert på denne serveren. I dokumentasjonen finner du detaljer om hvordan du {linkstart1}bygger din egen bot{linkend} eller en {linkstart2}-liste over roboter{linkend} som skal aktiveres på serveren din.",
    "No bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Ingen roboter er installert på denne serveren. I dokumentasjonen finner du detaljer om hvordan du {linkstart1}bygger din egen bot{linkend} eller en {linkstart2}-liste over roboter{linkend} som skal aktiveres på serveren din.",
    "Description is not provided" : "Beskrivelse er ikke gitt",
    "Locked for moderators" : "Låst for moderatorer",
    "Enabled" : "Aktivert",
    "Disabled" : "Deaktivert",
    "Bots settings" : "Innstillinger for roboter",
    "State" : "Tilstand",
    "Name" : "Navn",
    "Last error" : "Siste feil",
    "Total errors count" : "Totalt antall feil",
    "Find more bots" : "Finn flere roboter",
    "Trusted servers can be configured at {linkstart}Sharing settings page{linkend}." : "Klarerte servere kan konfigureres på {linkstart}siden med innstillinger for deling{linkedin}.",
    "Beta" : "Beta",
    "Enable Federation in Talk app" : "Aktiver Federation i Talk-appen",
    "Permissions" : "Rettigheter",
    "Allow users to be invited to federated conversations" : "Tillat brukere å bli invitert til sammenknyttede samtaler",
    "Allow users to invite federated users into conversation" : "Tillat brukere å invitere sammenknyttede brukere til samtale",
    "Only allow to federate with trusted servers" : "Tillat bare å forene med pålitelige servere",
    "When at least one group is selected, only people of the listed groups can invite federated users to conversations." : "Når minst én gruppe er valgt, kan bare personer i de oppførte gruppene invitere sammenknyttede brukere til samtaler.",
    "Groups allowed to invite federated users" : "Grupper som har tillatelse til å invitere sammenknyttede brukere",
    "Select groups …" : "Velg grupper...",
    "All messages" : "Alle meldinger",
    "@-mentions only" : "kun @-nevner",
    "Off" : "ett kvarter",
    "General settings" : "Generelle innstillinger",
    "Default notification settings" : "Standard varslingsinnstillinger",
    "Default group notification" : "Standard gruppevarsling",
    "Default group notification for new groups" : "Standard gruppevarsling for nye grupper",
    "Integration into other apps" : "Integrering i andre apper",
    "Allow conversations on files" : "Tillat samtaler på Files",
    "Allow conversations on public shares for files" : "Tillat samtaler på delte offentlige ressurser for Files ",
    "Enable encryption" : "Aktiver kryptering",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "Ved å klikke på knappen over sendes informasjonen i skjemaet til serverne til Struktur AG. Du finner mer informasjon på {linkstart}spreed.eu{linkend}.",
    "Pending" : "Venter",
    "Error" : "Feil",
    "Blocked" : "Blokkert",
    "Active" : "Aktiv",
    "Expired" : "Utløpt",
    "Never" : "Aldri",
    "The trial could not be requested. Please try again later." : "Prøveversjonen kunne ikke bes om. Vennligst forsøk igjen senere.",
    "The account could not be deleted. Please try again later." : "Kontoen kunne ikke slettes. Vennligst forsøk igjen senere.",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "Vår partner Struktur AG leverer en tjeneste der en vertsbasert signalserver kan forespørres. For dette trenger du bare å fylle ut skjemaet nedenfor og din Nextcloud vil be om det. Når serveren er satt opp for deg, fylles legitimasjonen automatisk. Dette vil overskrive de eksisterende signalserverinnstillingene.",
    "URL of this Nextcloud instance" : "Nettadressen til denne Nextcloud-forekomsten",
    "Full name of the user requesting the trial" : "Fullt navn på brukeren som ber om prøveversjonen",
    "Email of the user" : "E-post til brukeren",
    "Language" : "Språk",
    "Country" : "Land",
    "Request signaling server trial" : "Be om prøveversjon av signalserver",
    "You can see the current status of your hosted signaling server in the following table." : "Du kan se gjeldende status for den vertsbaserte signalserveren i tabellen nedenfor.",
    "Status" : "Status",
    "Created at" : "Opprettet den",
    "Expires at" : "Utløper",
    "Limits" : "Grenser",
    "Yes" : "Ja",
    "No" : "Nei",
    "Delete the signaling server account" : "Slett signalserverkontoen",
    "_%n user_::_%n users_" : ["%n bruker","%n brukere"],
    "Installed version: {version}" : "Installert versjon: {version}",
    "You can install the Matterbridge to link Nextcloud Talk to some other services, visit their {linkstart1}GitHub page{linkend} for more details. Downloading and installing the app can take a while. In case it times out, please install it manually from the {linkstart2}Nextcloud App Store{linkend}." : "Du kan installere Matterbridge for å koble Nextcloud Talk til noen andre tjenester, besøk deres {linkstart1}GitHub-side{linkend} for mer informasjon. Det kan ta litt tid å laste ned og installere appen. I tilfelle det blir tidsavbrutt, kan du installere det manuelt fra {linkstart2}Nextcloud App Store {linkend}.",
    "Matterbridge binary was not found or couldn't be executed." : "Matterbridge-binær ble ikke funnet eller kunne ikke utføres.",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "Du kan også angi stien til Matterbridge-binæren manuelt via konfigurasjonen. Se {linkstart}dokumentasjonen for Matterbridge-integrering{linkend} for mer informasjon.",
    "Downloading …" : "Laster ned …",
    "Install Talk Matterbridge" : "Installer Talk Matterbridge",
    "An error occurred while installing the Matterbridge app" : "Det oppstod en feil under installasjon av Matterbridge-appen",
    "An error occurred while installing the Talk Matterbridge. Please install it manually" : "Det oppstod en feil under installasjon av Talk Matterbridge. Vennligst installer det manuelt.",
    "Failed to execute Matterbridge binary." : "Utførelse av Matterbridge-binær feilet.",
    "Matterbridge integration" : "Integrasjon av Matterbridge",
    "Enable Matterbridge integration" : "Aktiver integrasjon av Matterbridge",
    "Status: Checking connection" : "Status: Sjekker tilkobling",
    "OK: Running version: {version}" : "OK: kjører versjon: {version}",
    "Error: Server seems to be a Signaling server" : "Feil: serveren ser ut til å være en signalserver",
    "Recording backend URL" : "Nettadresse til opptaks-backend",
    "Validate SSL certificate" : "Bekreft SSL-sertifikat",
    "Delete this server" : "Slett denne serveren",
    "Test this server" : "Test denne serveren",
    "Disabled for all calls" : "Deaktivert for alle anrop",
    "Enabled for all calls" : "Aktivert for alle anrop",
    "Configurable on conversation level by moderators" : "Kan konfigureres på samtalenivå av moderatorer",
    "The PHP settings \"upload_max_filesize\" or \"post_max_size\" only will allow to upload files up to {maxUpload}." : "PHP-innstillingene \"upload_max_filesize\" eller \"post_max_size\" vil bare tillate å laste opp filer opptil {maxUpload}.",
    "Recording backend settings saved" : "Innstillingene for opptaks-backend lagret",
    "Moderators will be allowed to enable consent on conversation level. The consent to be recorded will be required for each participant before joining every call in this conversation." : "Moderatorer kan aktivere samtykke på samtalenivå. Samtykket som skal registreres vil være nødvendig for hver deltaker før han blir med i hver samtale i denne samtalen.",
    "The consent to be recorded will be required for each participant before joining every call." : "Samtykket som skal registreres vil være nødvendig for hver deltaker før du blir med i hver samtale.",
    "The consent to be recorded is not required." : "Samtykket som skal registreres er ikke nødvendig.",
    "Add a new recording backend server" : "Legg til en ny opptaks-backend server",
    "Shared secret" : "Delt hemmelighet",
    "Recording consent" : "Samtykke til opptak",
    "SIP configuration saved!" : "SIP-konfigurasjon lagret!",
    "Enable SIP Dial-out option" : "Aktiver SIP-utringningsalternativ",
    "Signaling server needs to be updated to supported SIP Dial-out feature." : "Signalserveren må oppdateres til støttet SIP-utringningsfunksjon.",
    "Restrict SIP configuration" : "Begrens SIP innstillinger",
    "Enable SIP configuration" : "Aktiver SIP innstillinger",
    "Only users of the following groups can enable SIP in conversations they moderate" : "Bare brukere av følgende grupper kan aktivere SIP i samtaler de modererer",
    "Phone number (Country)" : "Telefonnumer (fast)",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "Denne informasjonen sendes i e-postinvitasjoner, samt vises i sidefeltet til alle deltakere.",
    "Error code" : "Feilkode",
    "High-performance backend URL" : "Nettadresse for backend med høy ytelse",
    "High-performance backend settings saved" : "Backend-innstillinger med høy ytelse lagret",
    "STUN server URL" : "STUN server URL",
    "The server address is invalid" : "Serveradressen er ugyldig",
    "STUN settings saved" : "STUN-innstillinger lagret",
    "STUN servers" : "STUN-server",
    "A STUN server is used to determine the public IP address of participants behind a router." : "En STUN-server brukes til å fastsette den offentlige IP-adressen for deltagere bak en ruter.",
    "Add a new STUN server" : "Legg til en ny STUN-server",
    "{schema} scheme must be used with a domain" : "{schema} skjema må brukes med et domene",
    "{option1} and {option2}" : "{option1} og {option2}",
    "{option} only" : "kun {option}",
    "OK: Successful ICE candidates returned by the TURN server" : "OK: vellykkede ICE-kandidater returnert av TURN-serveren",
    "Error: No working ICE candidates returned by the TURN server" : "Feil: ingen fungerende ICE-kandidater returnert av TURN-serveren",
    "Testing whether the TURN server returns ICE candidates" : "Tester om TURN-serveren returnerer ICE-kandidater",
    "TURN server schemes" : "TURN-serverskjemaer",
    "TURN server URL" : "TURN server URL",
    "TURN server secret" : "TURN-server hemmelighet",
    "TURN server protocols" : "TURN-serverprotokoller",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "En TURN-server brukes til å proxy-tjene trafikken fra deltakere bak en brannmur. Hvis individuelle deltakere ikke kan koble til andre, er det mest sannsynlig nødvendig med en TURN-server. Se {linkstart}denne dokumentasjonen{linkend} for installasjonsinstruksjoner.",
    "TURN settings saved" : "TURN-innstillinger lagret",
    "TURN servers" : "TURN-servere",
    "Add a new TURN server" : "Legg til en ny TURN-server",
    "Failed" : "Mislyktes",
    "OK" : "OK",
    "Checking …" : "Sjekker…",
    "Failed: WebAssembly is disabled or not supported in this browser. Please enable WebAssembly or use a browser with support for it to do the check." : "Feilet: WebAssembly er deaktivert eller støttes ikke i denne nettleseren. Vennligst aktiver WebAssembly eller bruk en nettleser med støtte for den for å gjøre sjekken.",
    "Failed: \".wasm\" and \".tflite\" files were not properly returned by the web server. Please check \"System requirements\" section in Talk documentation." : "Feilet: \".wasm\"- og .tflite\"-filer ble ikke returnert på riktig måte av webserveren. Sjekk avsnittet \"Systemkrav\" i Talk-dokumentasjonen.",
    "OK: \".wasm\" and \".tflite\" files were properly returned by the web server." : "OK: \".wasm\"- og .tflite\"-filer ble returnert på riktig måte av webserveren.",
    "It seems that the PHP and Apache configuration is not compatible. Please note that PHP can only be used with the MPM_PREFORK module and PHP-FPM can only be used with the MPM_EVENT module." : "Det ser ut til at PHP- og Apache-konfigurasjonen ikke er kompatibel. Vær oppmerksom på at PHP bare kan brukes med MPM_PREFORK-modulen, og PHP-FPM kan bare brukes med MPM_EVENT-modulen.",
    "Web server setup checks" : "Kontroller for oppsett av webserver",
    "Files required for virtual background can be loaded" : "Filer som kreves for virtuell bakgrunn kan lastes inn",
    "Federated user" : "Forent bruker",
    "Assign participants to rooms" : "Tildel deltakere til rom",
    "Configure breakout rooms" : "Konfigurer grupperom",
    "Number of breakout rooms" : "Antall grupperom",
    "You can create from 1 to 20 breakout rooms." : "Du kan opprette fra 1 til 20 grupperom.",
    "Assignment method" : "Tildelingsmetode",
    "Automatically assign participants" : "Tildel deltakere automatisk",
    "Manually assign participants" : "Tildel deltakere manuelt",
    "Allow participants to choose" : "La deltakerne velge",
    "Create rooms" : "Opprett rom",
    "Confirm" : "Bekreft",
    "Create breakout rooms" : "Opprett grupperom",
    "Reset" : "Tilbakestill",
    "Delete breakout rooms" : "Slett grupperom",
    "Room {roomNumber}" : "Rom {roomNumber}",
    "Current breakout rooms and settings will be lost" : "Gjeldende grupperom og innstillinger vil gå tapt",
    "Cancel" : "Avbryt",
    "Unassigned participants" : "Ikke-tilordnede deltakere",
    "Back" : "Tilbake",
    "Assign" : "Tildel",
    "Add participant \"{user}\"" : "Legg til deltaker \"{user}\"",
    "Now" : "Nå",
    "From" : "Fra",
    "To" : "Til",
    "Calendar" : "Kalender",
    "Attendees" : "Deltakere",
    "Save" : "Lagre",
    "Search participants" : "Søk etter deltakere",
    "No results" : "Ingen resultater",
    "Done" : "Ferdig",
    "Exit full screen (F)" : "Avslutt fullskjerm (F)",
    "Full screen (F)" : "Fullskjerm (F)",
    "Speaker view" : "Høyttalervisning",
    "Grid view" : "Rutenett-visning",
    "Recording consent is required" : "Samtykke til opptak kreves",
    "This conversation is read-only" : "Denne samtalen er skrivebeskyttet",
    "Connection failed" : "Tilkobling feilet",
    "Reload" : "Last på nytt",
    "{nickName} raised their hand." : "{nickName} rakte opp hånden.",
    "A participant raised their hand." : "En deltaker løftet hånden.",
    "Collapse stripe" : "Skjul stripe",
    "Expand stripe" : "Utvid stripe",
    "Previous page of videos" : "Forrige side med videoer",
    "Next page of videos" : "Neste side med videoer",
    "Connecting …" : "Kobler til...",
    "Calling …" : "Ringer...",
    "Waiting for {user} to join the call" : "Venter på at {user} skal bli med i samtalen",
    "Waiting for others to join the call …" : "Venter på at andre blir med i samtalen…",
    "You can invite others in the participant tab of the sidebar" : "Du kan invitere andre fra deltagerfanen i sidepanel",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Du kan invitere andre i deltagerfanen av sidepanel eller dele denne lenke for å invitere andre!",
    "Share this link to invite others!" : "Klikk denne lenken for å invitere andre.",
    "Copy link" : "Kopier lenke",
    "You are not allowed to enable audio" : "Du har ikke lov til å aktivere lyd",
    "No audio. Click to select device" : "Ingen lyd. Klikk for å velge enhet.",
    "Mute audio" : "Slå av lyd",
    "Mute audio (M)" : "Demp lyd (M)",
    "Unmute audio" : "Slå på lyd",
    "Unmute audio (M)" : "Slå på lyden (M)",
    "None" : "Ingen",
    "Access to camera was denied" : "Tilgang til kamera ble nektet",
    "Error while accessing camera: It is likely in use by another program" : "Feil under tilgang til kamera: det er sannsynligvis i bruk av et annet program.",
    "Error while accessing camera" : "Feil under tilgang til kameraet",
    "You have been muted by a moderator" : "En moderator har dempet deg",
    "Hide presenter video" : "Skjul presentatørvideo",
    "You are not allowed to enable video" : "Du har ikke lov til å aktivere video",
    "No video. Click to select device" : "Ingen video. Klikk for å velge enhet.",
    "Disable video" : "Skru av video",
    "Disable video (V)" : "Deaktiver video (V)",
    "Enable video" : "Skru på video",
    "Enable video (V)" : "Aktiver video (V)",
    "Enable video - Your connection will be briefly interrupted when enabling the video for the first time" : "Aktiver video – tilkoblingen din blir kort avbrutt når du aktiverer videoen for første gang",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Aktiver video (V) – tilkoblingen din blir kort avbrutt når du aktiverer videoen for første gang",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Aktiver video – tilkoblingen din blir kort avbrutt når du aktiverer videoen for første gang",
    "Show presenter" : "Vis presentatør",
    "You" : "Du",
    "Mute" : "Dempe",
    "Muted" : "Dempet",
    "Show screen" : "Vis skjerm",
    "Stop following" : "Slutt å følge",
    "Connection could not be established …" : "Forbindelsen kunne ikke opprettes...",
    "Connection was lost and could not be re-established …" : "Forbindelsen ble brutt og kunne ikke gjenopprettes…",
    "Connection could not be established. Trying again …" : "Forbindelsen kunne ikke opprettes. Forsøker igjen...",
    "Connection lost. Trying to reconnect …" : "Forbindelsen er brutt. Prøver å koble til igjen…",
    "Connection problems …" : "Tilkoblingsproblemer...",
    "Collapse" : "Skjul",
    "Expand" : "Ekspander",
    "You need to be logged in to upload files" : "Du må være på logget for å laste opp filer",
    "Drop your files to upload" : "Dropp filer for å laste opp",
    "Conversation messages" : "Samtale meldinger",
    "Scroll to bottom" : "Rull til bunnen",
    "Post message" : "Send melding",
    "Federated conversation" : "Forent samtale",
    "Public conversation" : "Offentlig samtale",
    "Favorite" : "Merk som favoritt",
    "Banned users" : "Utestengte brukere",
    "Manage the list of banned users in this conversation." : "Administrer listen over utestengte brukere i denne samtalen.",
    "Manage bans" : "Administrer utestengelser",
    "No banned users" : "Ingen utestengte brukere",
    "Banned by:" : "Utestengt av:",
    "Date:" : "Dato:",
    "Note:" : "Merk:",
    "Hide details" : "Skjul detaljer",
    "Show details" : "Vis detaljer",
    "Unban" : "Opphev utestengelsen",
    "Error while updating conversation name" : "Feil under oppdatering av samtalenavn",
    "Error while updating conversation description" : "Feil under oppdatering av samtalebeskrivelse",
    "Enter a name for this conversation" : "Skriv inn et navn for denne samtalen",
    "Edit conversation name" : "Rediger samtalenavn",
    "Edit conversation description" : "Rediger samtalebeskrivelse",
    "Enter a description for this conversation" : "Skriv inn en beskrivelse for denne samtalen",
    "Picture" : "Bilde",
    "The following bots can be enabled in this conversation. Reach out to your administration to get more bots installed on this server." : "Følgende roboter kan aktiveres i denne samtalen. Ta kontakt med administrasjonen din for å få flere roboter installert på denne serveren.",
    "No bots are installed on this server. Reach out to your administration to get bots installed on this server." : "Ingen roboter er installert på denne serveren. Ta kontakt med administrasjonen din for å få roboter installert på denne serveren.",
    "Disable" : "Deaktiver",
    "Enable" : "Aktiver",
    "Breakout rooms" : "Grupperom",
    "Manage breakout rooms" : "Administrer grupperom",
    "Set up breakout rooms for this conversation" : "Sett opp grupperom for denne samtalen",
    "Please select a valid PNG or JPG file" : "Vennligst velg en gyldig PNG eller JPG-fil",
    "Choose your conversation picture" : "Velg ditt samtalebilde",
    "Choose" : "Velg",
    "Error setting conversation picture" : "Feil ved innstilling av samtalebilde",
    "Could not set the conversation picture: {error}" : "Kunne ikke angi samtalebildet: {error}",
    "Error cropping conversation picture" : "Feil ved beskjæring av samtalebilde",
    "Error removing conversation picture" : "Feil ved fjerning av samtalebilde",
    "Set emoji as conversation picture" : "Angi emoji som samtalebilde",
    "Set background color for conversation picture" : "Angi bakgrunnsfarge for samtalebilde",
    "Upload conversation picture" : "Last opp samtalebilde",
    "Choose conversation picture from files" : "Velg samtalebilde blant filer",
    "Remove conversation picture" : "Fjern samtalebilde",
    "The file must be a PNG or JPG" : "Filen må være en .PNG eller .JPG",
    "Set picture" : "Angi bilde",
    "Default permissions modified for {conversationName}" : "Standard rettigheter modifisert for {conversationName}",
    "Could not modify default permissions for {conversationName}" : "Kunne ikke modifisere standard rettigheter for {conversationName}",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "Rediger standardtillatelsene for deltakere i denne samtalen. Disse innstillingene påvirker ikke moderatorer.",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "Hver gang tillatelser endres i denne delen, går egendefinerte tillatelser som tidligere var tildelt individuelle deltakere, tapt.",
    "All permissions" : "Alle rettigheter",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "Deltakerne har rettigheter til å starte en samtale, bli med i en samtale, aktivere lyd og video og dele skjermen.",
    "Restricted" : "Begrenset",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Deltakere kan bli med i samtaler, men kan ikke aktivere lyd eller video eller dele skjerm før en moderator manuelt gir dem tillatelser.",
    "Advanced permissions" : "Avanserte rettigheter",
    "Edit permissions" : "Rediger rettigheter",
    "Conversation settings" : "Samtale innstillinger",
    "Basic Info" : "Grunnleggende informasjon",
    "Personal" : "Personlig",
    "Moderation" : "Moderering",
    "Setup overview" : "Oversikt over oppsett",
    "Breakout Rooms" : "Grupperom",
    "Matterbridge" : "Matterbridge",
    "Bots" : "Roboter",
    "Danger zone" : "Faresone",
    "Leave conversation" : "Forlat samtale",
    "You need to promote a new moderator before you can leave the conversation" : "Du må forfremme en ny moderator før du kan forlate samtalen",
    "Delete conversation" : "Slett samtale",
    "Do you really want to delete \"{displayName}\"?" : "Vil du virkelig slette \"{displayName}\"?",
    "Error while deleting conversation" : "Feil under sletting av samtale",
    "Delete all chat messages" : "Slett alle meldinger",
    "Do you really want to delete all messages in \"{displayName}\"?" : "Vil du virkelig slette alle meldinger i \"{displayName}\"?",
    "Error while clearing chat history" : "Det oppsto en feil. Kan ikke slette meldingslogg",
    "Be careful, these actions cannot be undone." : "Vær forsiktig, disse handlingene kan ikke angres.",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Når en samtale forlates, er det nødvendig med en invitasjon for å bli med i en lukket samtale igjen. En åpen samtale kan når som helst kobles til igjen.",
    "Permanently delete this conversation." : "Slett denne samtalen permanent.",
    "Delete chat messages" : "Slett melding",
    "Permanently delete all the messages in this conversation." : "Slett alle meldingene i denne samtalen permanent.",
    "Custom expiration time" : "Brukerdefinert utløpstid for melding",
    "Message expiration disabled" : "Utløpstid for melding deaktivert",
    "Message expiration set: {duration}" : "Utløpstid for melding angitt: {duration}",
    "Error when trying to set message expiration" : "Feil ved forsøk på å angi utløpstid for melding",
    "Message expiration" : "Utløp av melding",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "Chatmeldinger kan utløpe etter en viss tid. Merk: filer som deles i chat, slettes ikke for eieren, men deles ikke lenger i samtalen.",
    "Set message expiration" : "Angi utløpstid for melding",
    "Current message expiration" : "Gjeldene utløpstid for melding",
    "Guest access" : "Gjestetilgang",
    "Breakout rooms are not allowed in public conversations." : "Grupperom er ikke tillatt i offentlige samtaler.",
    "Allow guests to join this conversation via link" : "Tillat gjester å delta i denne samtalen via kobling",
    "Password protection" : "Passordbeskyttelse",
    "Set a password" : "Sett et passord",
    "Change password" : "Endre passord",
    "Enter new password" : "Angi nytt passord",
    "Save password" : "Lagre passord",
    "Guests are allowed to join this conversation via link" : "Gjester kan delta i denne samtalen via kobling",
    "Guests are not allowed to join this conversation" : "Gjester kan ikke delta i denne samtalen",
    "Resend invitations" : "Send invitasjoner på nytt",
    "This conversation is open to both registered users and users created with the Guests app" : "Denne samtalen er åpen for både registrerte brukere og brukere som er opprettet med Guests-appen",
    "This conversation is open to registered users" : "Denne samtalen er åpen for registrerte brukere",
    "This conversation is limited to the current participants" : "Denne samtalen er begrenset til de nåværende deltakerne",
    "You opened the conversation to both registered users and users created with the Guests app" : "Du åpnet samtalen for både registrerte brukere og brukere som er opprettet med Guests-appen",
    "Error occurred when opening or limiting the conversation" : "Det oppstod en feil under åpning eller begrensning av samtalen",
    "Open conversation to registered users, showing it in search results" : "Åpne samtalen for registrerte brukere, vis den i søkeresultatene",
    "Also open to users created with the Guests app" : "Også åpen for brukere som er opprettet med Guests-appen",
    "Open conversation" : "Åpen samtale",
    "Invalid language" : "Ugyldig språk",
    "Start time: {date}" : "Starttidspunkt: {date}",
    "Start time has been updated" : "Starttidspunkt har blitt oppdatert",
    "Error occurred while updating start time" : "Det oppstod en feil under oppdatering av starttid",
    "Enabling the lobby will remove non-moderators from the ongoing call." : "Aktivering av lobbyen vil fjerne ikke-moderatorer fra den pågående samtalen.",
    "Enable lobby, restricting the conversation to moderators" : "Aktiver lobbyen, og begrens samtalen til moderatorer",
    "Meeting start time" : "Møtets starttidspunkt",
    "Start time (optional)" : "Starttidspunkt (valgfri)",
    "Error occurred when locking the conversation" : "Det oppstod en feil under låsing av samtalen",
    "Error occurred when unlocking the conversation" : "Det oppstod en feil under opplåsing av samtalen",
    "Lock conversation" : "Lås samtalen",
    "This will also terminate the ongoing call." : "Dette vil også avslutte den pågående samtalen.",
    "Lock the conversation to prevent anyone to post messages or start calls" : "Lås samtalen for å hindre at noen legger inn meldinger eller starter samtaler",
    "Edit" : "Rediger",
    "More information" : "Mer informasjon",
    "Delete" : "Slett",
    "Add new bridged channel to current conversation" : "Legg til ny brokoblet kanal til gjeldende samtale",
    "unknown state" : "ukjent tilstand",
    "running" : "kjører",
    "not running, check Matterbridge log" : "kjører ikke, sjekk loggen til Matterbridge",
    "not running" : "kjører ikke",
    "Bridge saved" : "Bro lagret",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "Du kan bygge bro mellom kanaler fra forskjellige direktemeldingssystemer med Matterbridge.",
    "More info on Matterbridge" : "Mer info om Matterbridge",
    "Messaging systems" : "Meldingssystemer",
    "Enable bridge" : "Aktiver bro",
    "Show Matterbridge log" : "Vis Matterbridge-logg",
    "Log content" : "Loggfør innhold",
    "Only moderators are allowed to mention @all" : "Bare moderatorer har lov til å nevne @all",
    "All participants are allowed to mention @all" : "Bare deltakere har lov til å nevne @all",
    "Participants are now allowed to mention @all." : "Deltakere har nå tillatelse til å nevne @all.",
    "Mentioning @all has been limited to moderators." : "Å nevne @all har blitt begrenset til moderatorer.",
    "Allow participants to mention @all" : "La deltakerne nevne @all",
    "Mention permissions" : "Nevn rettigheter",
    "Notifications" : "Varsler",
    "Notify about calls in this conversation" : "Varsle om anrop i denne samtalen",
    "Important conversation" : "Viktig samtale",
    "Recording consent is required for calls in this conversation" : "Det kreves samtykke til opptak av anrop i denne samtalen",
    "Recording consent is not required for calls in this conversation" : "Samtykke til opptak er ikke nødvendig for anrop i denne samtalen",
    "Recording consent requirement was updated" : "Samtykkekravet for opptak ble oppdatert",
    "Error occurred while updating recording consent" : "Det oppstod en feil under oppdatering av samtykke til opptak",
    "Recording Consent" : "Samtykke til opptak",
    "Recording consent cannot be changed once a call or breakout session has started." : "Samtykke til opptak kan ikke endres når en samtale- eller grupperomøkt har startet.",
    "Require recording consent before joining call in this conversation" : "Krev samtykke til opptak før du blir med i samtalen i denne samtalen",
    "Recording consent is required for all calls" : "Det kreves samtykke til opptak for alle samtaler",
    "SIP dial-in is now possible without PIN requirement" : "SIP-innringing er nå mulig uten krav om PIN-kode",
    "SIP dial-in is now enabled" : "SIP-innringing er nå aktivert",
    "SIP dial-in is now disabled" : "SIP-innringing er nå deaktivert",
    "Error occurred when enabling SIP dial-in" : "Feil oppstod under aktivering av SIP-innringing",
    "Error occurred when disabling SIP dial-in" : "Feil oppstod under deaktivering av SIP-innringing",
    "Phone and SIP dial-in" : "Telefon- og SIP-innringing",
    "Enable phone and SIP dial-in" : "Aktiver telefon- og SIP-innringing",
    "Allow to dial-in without a PIN" : "Tillat innringing uten PIN-kode",
    "Join" : "Bli med",
    "Error while creating the conversation" : "Feil under oppretting av samtalen",
    "Create a new conversation" : "Opprett en ny samtale",
    "Join open conversations" : "Bli med i åpne samtaler",
    "Call a phone number" : "Ring et telefonnummer",
    "Unread mentions" : "Uleste nevner",
    "Create conversation" : "Opprett samtale",
    "Enter your name" : "Skriv inn navnet ditt",
    "Submit name and join" : "Send inn navn og bli med",
    "Do you already have an account?" : "Har du allerede en konto?",
    "Log in" : "Logg inn",
    "An error occurred while calling a phone number" : "Det oppstod en feil under anrop av et telefonnummer",
    "Phone number could not be called: {error}" : "Telefonnummer kunne ikke ringes: {error}",
    "Phone number could not be called" : "Telefonnummer kunne ikke ringes",
    "Search participants or phone numbers" : "Søk etter deltakere eller telefonnumre",
    "Creating the conversation …" : "Oppretter samtalen...",
    "Mark as read" : "Merk som lest",
    "Mark as unread" : "Merk som ulest",
    "Remove from favorites" : "Fjern fra favoritter",
    "Add to favorites" : "Legg til i favoritter",
    "You need to promote a new moderator before you can leave the conversation." : "Du må utnevne en ny moderator før du kan forlate samtalen.",
    "New tag" : "Ny merkelapp",
    "Tag name" : "Navn på merkelapp",
    "Conversation actions" : "Samtalehandlinger",
    "Tags" : "Merkelapper",
    "Rename tag" : "Gi nytt navn til taggen",
    "Delete tag" : "Slett merke",
    "Move up" : "Flytt opp",
    "Move down" : "Flytt ned",
    "Pending invitations" : "Ventende invitasjoner",
    "From {user} at {remoteServer}" : "Fra {user} ved {remoteServer}",
    "Decline invitation" : "Avslå invitasjon",
    "Accept invitation" : "Aksepter invitasjon",
    "No pending invitations" : "Ingen ventende invitasjoner",
    "Home" : "Hjem",
    "Unread" : "Ulest",
    "Alphabetically" : "Alfabetisk",
    "No matches found" : "Ingen treff funnet",
    "No conversations found" : "Ingen samtaler funnet",
    "You have no unread mentions." : "Du har ingen uleste nevner",
    "You have no unread messages." : "Du har ingen uleste meldinger",
    "An error occurred while performing the search" : "Det oppstod en feil under utføring av søket",
    "Conversation list" : "Samtaleliste",
    "Unread messages" : "Uleste meldinger",
    "Clear filters" : "Tøm filtre",
    "New personal note" : "Nytt personlig notat",
    "Clear filter" : "Tøm filter",
    "App settings" : "App-innstillinger",
    "Users" : "Brukere",
    "Groups" : "Grupper",
    "Teams" : "Lag",
    "Federated users" : "Forente brukere",
    "New private conversation" : "Ny privat samtale",
    "Other sources" : "Andre kilder",
    "Open conversations" : "Åpne samtaler",
    "No search results" : "Ingen søkeresultater",
    "Users, groups and teams" : "Brukere, grupper og lag",
    "Users and groups" : "Brukere og grupper",
    "Users and teams" : "Brukere og lag",
    "Groups and teams" : "Grupper og lag",
    "New group conversation" : "Ny gruppesamtale",
    "The meeting will start soon" : "Møtet starter snart",
    "This meeting is scheduled for {startTime}" : "Dette møtet er planlagt til {startTime}",
    "You are currently waiting in the lobby" : "Du venter for øyeblikket i lobbyen",
    "Advanced" : "Avansert",
    "Select microphone" : "Velg mikrofon",
    "No microphone available" : "Ingen mikrofon er tilgjengelig",
    "Select camera" : "Velg kamera",
    "No camera available" : "Ingen kamera tilgjengelig",
    "Select a device" : "Velg en enhet",
    "Playing …" : "Spiller...",
    "Test speakers" : "Test høyttalere",
    "Test" : "Test",
    "Devices" : "Enheter",
    "Backgrounds" : "Bakgrunner",
    "No audio" : "Ingen lyd",
    "No camera" : "Ikke noe kamera",
    "Display video as you will see it (mirrored)" : "Vis video slik du vil se den (speilet)",
    "Display video as others will see it" : "Vis video slik andre vil se den",
    "Calls are not supported in your browser" : "Anrop støttes ikke i nettleseren din",
    "Access to microphone is only possible with HTTPS" : "Tilgang til mikrofon er bare mulig med HTTPS",
    "Access to microphone was denied" : "Tilgang til mikrofon ble nektet",
    "Error while accessing microphone" : "Feil under tilgang til mikrofon",
    "Access to camera is only possible with HTTPS" : "Tilgang til kamera er bare mulig med HTTPS",
    "The call is being recorded." : "Samtalen blir tatt opp.",
    "The call might be recorded." : "Samtalen kan bli tatt opp.",
    "The recording might include your voice, video from camera, and screen share. Your consent is required before joining the call." : "Opptaket kan inneholde stemmen din, video fra kamera og skjermdeling. Ditt samtykke kreves før du blir med i samtalen.",
    "Give consent to the recording of this call" : "Gi samtykke til opptak av denne samtalen",
    "Start recording immediately with the call" : "Start opptaket umiddelbart med samtalen",
    "Apply settings" : "Anvend innstillinger",
    "Select virtual office background" : "Velg virtuell kontorbakgrunn",
    "Select virtual home background" : "Velg virtuell hjemmebakgrunn",
    "Select virtual abstract background" : "Velg virtuell abstrakt bakgrunn",
    "Select virtual beach background" : "Velg virtuell strandbakgrunn",
    "Select virtual park background" : "Velg virtuell parkbakgrunn",
    "Select virtual theater background" : "Velg virtuell teaterbakgrunn",
    "Select virtual library background" : "Velg virtuell biblioteksbakgrunn",
    "Select virtual space station background" : "Velg bakgrunn for virtuell romstasjon",
    "Error while uploading the file" : "Feil under opplasting av filen",
    "Select a file" : "Velg en fil",
    "Invalid path selected" : "Ugyldig angitt sti",
    "Select virtual background from file {fileName}" : "Velg virtuell bakgrunn fra fil {fileName}",
    "Blur" : "Uklar",
    "Upload" : "Last opp",
    "Files" : "Filer",
    "(editing)" : "(redigerer)",
    "(edited)" : "(redigert)",
    "The message has expired or has been deleted" : "Denne meldingen er utløpt eller slettet",
    "Cancel quote" : "Avbryt tilbud",
    "24 hours" : "24 timer",
    "7 days" : "7 dager",
    "Clear reminder – {timeLocale}" : "Tydelig påminnelse – {timeLocale}",
    "Edited by {actor}" : "Redigert av {actor}",
    "Message text copied to clipboard" : "Meldingstekst kopiert til utklippstavlen",
    "Message text could not be copied" : "Meldingsteksten kunne ikke kopieres",
    "Message forwarded to \"Note to self\"" : "Melding videresend til \"Notat til meg selv\"",
    "Error while forwarding message to \"Note to self\"" : "Feil under videresending av melding til \"Notat til meg selv\"",
    "A reminder was successfully removed" : "En påminnelse ble fjernet",
    "Error occurred when removing a reminder" : "Det oppstod en feil under fjerning av en påminnelse",
    "A reminder was successfully set at {datetime}" : "En påminnelse ble satt kl. {datetime}",
    "Error occurred when creating a reminder" : "Det oppstod en feil under oppretting av en påminnelse",
    "Add a reaction to this message" : "Legg til en reaksjon på denne meldingen",
    "Reply" : "Svar",
    "More actions" : "Flere handlinger",
    "Set reminder" : "Angi påminnelse",
    "Reply privately" : "Svar privat",
    "Edit message" : "Rediger melding",
    "Copy message" : "Kopier melding",
    "Copy message link" : "Kopier meldingskobling",
    "Go to file" : "Gå til fil",
    "Forward message" : "Videresend melding",
    "Translate" : "Oversette",
    "Set custom reminder" : "Angi egendefinert påminnelse",
    "Close reactions menu" : "Lukk reaksjonsmenyen",
    "React with {emoji}" : "Reager med {emoji}",
    "React with another emoji" : "Reager med en annen emoji",
    "Choose a conversation to forward the selected message." : "Velg en samtale for å videresende den merkede meldingen.",
    "Error while forwarding message" : "Feil under videresending av melding",
    "The message has been forwarded to {selectedConversationName}" : "Meldingen er videresendt til {selectedConversationName}",
    "Dismiss" : "Forkast",
    "Go to conversation" : "Gå til samtale",
    "Detect language" : "Oppdag språk",
    "The message could not be translated" : "Meldingen kan ikke oversettes",
    "Translation copied to clipboard" : "Oversettelsen kopier til utklippstavlen",
    "Translation could not be copied" : "Oversettelsen kunne ikke kopieres",
    "Translate message" : "Oversett melding",
    "Source language to translate from" : "Kildespråk å oversette fra",
    "Translate from" : "Oversett fra",
    "Target language to translate into" : "Målspråk å oversette til",
    "Translate to" : "Oversett til",
    "Translating" : "Oversetter",
    "Copy translated text" : "Kopier oversatt tekst",
    "Send now" : "Send nå",
    "Message read by everyone who shares their reading status" : "Melding lest av alle som deler sin lesestatus",
    "Message sent" : "Melding sendt",
    "Deleting message" : "Sletter melding",
    "Message deleted successfully, but a bot or Matterbridge is configured and the message might already be distributed to other services" : "Meldingen er slettet, men en robot eller Matterbridge er konfigurert, og meldingen kan allerede være distribuert til andre tjenester",
    "Message deleted successfully" : "Melding slettet",
    "Message could not be deleted because it is too old" : "Meldingen kunne ikke slettes fordi den er for gammel",
    "Only normal chat messages can be deleted" : "Kun vanlige meldinger kan slettes",
    "An error occurred while deleting the message" : "Det oppstod en feil under sletting av meldingen",
    "Your browser does not support playing audio files" : "Nettleseren din støtter ikke avspilling av lydfiler",
    "Contact" : "Kontakt",
    "{stack} in {board}" : "{stack} i {board}",
    "Deck Card" : "Deck-kort",
    "Remove {fileName}" : "Fjern {fileName}",
    "Open this location in OpenStreetMap" : "Åpne denne plasseringen i OpenStreetMap",
    "Sending message" : "Sender melding",
    "Failed to send the message. Click to try again" : "Kunne ikke sende meldingen. Klikk for å prøve igjen.",
    "Not enough free space to upload file" : "Ikke nok ledig plass til å laste opp fil",
    "You cannot send messages to this conversation at the moment" : "Du kan ikke sende meldinger til denne samtalen for øyeblikket",
    "Could not update the message" : "Kunne ikke oppdatere meldingen",
    "You voted" : "Du stemte",
    "_%n vote_::_%n votes_" : ["%n stemme","%n stemmer"],
    "Open poll" : "Åpen avstemning",
    "See results" : "Vis resultater",
    "Reactions" : "Reaksjoner",
    "No permission to post reactions in this conversation" : "Ingen tillatelse til å legge inn reaksjoner i denne samtalen",
    "and {participant}" : "og {participant}",
    "_and %n other participant_::_and %n other participants_" : ["og %n deltaker til","og %n andre deltakere"],
    "Show all reactions" : "Vis alle reaksjoner",
    "Add more reactions" : "Legg til flere reaksjoner",
    "Show or collapse system messages" : "Vis eller skjul systemmeldinger",
    "No messages" : "Ingen meldinger",
    "All messages have expired or have been deleted." : "Alle meldinger er utløpt eller slettet.",
    "Unpin" : "Løsne",
    "Cancel search" : "Avbryt søk",
    "Add a phone number" : "Legg til et telefonnummer",
    "All set, the conversation \"{conversationName}\" was created." : "Alt klart, samtalen \"{conversationName}\" ble opprettet.",
    "Create a new group conversation" : "Opprett en ny gruppesamtale",
    "Add participants" : "Legg til deltager",
    "Maximum length exceeded ({maxlength} characters)" : "Maksimal lengde overskredet ({maxlength} tegn)",
    "Conversation visibility" : "Synlighet for samtale",
    "Allow guests to join via link" : "Tillat gjester å bli med via kobling",
    "Enter password" : "Skriv inn passord",
    "This conversation has been locked" : "Samtalen er låst",
    "No permission to post messages in this conversation" : "Ingen tillatelse til å legge ut meldinger i denne samtalen",
    "Joining conversation …" : "Blir med i samtalen...",
    "Send message silently" : "Send melding stille",
    "Send message" : "Send melding",
    "Send without notification" : "Send uten varsel",
    "The participant will not be notified about new messages" : "Mottakeren blir ikke varslet om nye meldinger",
    "Participants will not be notified about new messages" : "Mottakere blir ikke varslet om nye meldinger",
    "The message could not be edited" : "Meldingen kunne ikke redigeres",
    "File to share" : "Fil for deling",
    "File upload is not available in this conversation" : "Filopplasting er ikke tilgjengelig i denne samtalen",
    "Add emoji" : "Legg til emoji",
    "Adding a mention will only notify users who did not read the message." : "Hvis du legger til en nevner, varsles bare brukere som ikke har lest meldingen.",
    "Send later" : "Send senere",
    "Cancel editing" : "Avbryt redigering",
    "{user} is out of office and might not respond." : "{user} er fraværende og svarer kanskje ikke.",
    "Share from {nextcloud}" : "Del fra {nextcloud}",
    "Share from Files" : "Del fra Filer",
    "Share files to the conversation" : "Del filer til samtalen",
    "Upload from device" : "Last opp fra enhet",
    "Create new poll" : "Opprett ny avstemning",
    "Smart picker" : "Smartvelger",
    "Record voice message" : "Ta opp talemelding",
    "End recording and send" : "Avslutt opptak og send",
    "Dismiss recording" : "Avvis opptak",
    "Access to the microphone was denied" : "Tilgang til mikrofonen ble nektet",
    "Microphone either not available or disabled in settings" : "Mikrofon enten ikke tilgjengelig eller deaktivert i innstillingene",
    "Error while recording audio" : "Feil under innspilling av lyd",
    "New file" : "Ny fil",
    "Blank" : "Blank",
    "Error while creating file" : "Feil under oppretting av fil",
    "Create and share a new file" : "Opprett og del en ny fil",
    "Name of the new file" : "Navn på ny fil",
    "Create file" : "Opprett fil",
    "Someone is typing …" : "Noen skriver…",
    "{user1} is typing …" : "{user1} skriver...",
    "{user1} and {user2} are typing …" : "{user1} og {user2} skriver...",
    "{user1}, {user2} and {user3} are typing …" : "{user1}, {user2} og {user3} skriver...",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}, {user2}, {user3} og %n annen skriver...","{user1}, {user2}, {user3} og %n andre skriver..."],
    "Add more files" : "Legg til flere filer",
    "Send" : "Send",
    "In this conversation <strong>{user}</strong> can:" : "I denne samtalen <strong>{user}</strong> kan:",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "Rediger standard rettigheter for deltakere i <strong>{conversationName}</strong>",
    "Start a call" : "Start et anrop",
    "Skip the lobby" : "Hopp over lobbyen",
    "Can post messages and reactions" : "Kan legge ut meldinger og reaksjoner",
    "Enable the microphone" : "Aktiver mikrofonen",
    "Enable the camera" : "Aktiver kameraet",
    "Share the screen" : "Del skjermen",
    "Update permissions" : "Oppdater rettigheter",
    "Updating permissions" : "Oppdaterer rettigheter",
    "Create poll" : "Opprett avstemning",
    "Question" : "Spørsmål",
    "Ask a question" : "Still et spørsmål",
    "Answers" : "Svar",
    "Answer {option}" : "Svar {option}",
    "Delete poll option" : "Slett avstemningsalternativet",
    "Add answer" : "Legg til svar",
    "Settings" : "Innstillinger",
    "Anonymous poll" : "Anonym avstemning",
    "Multiple answers" : "Flere svar",
    "You voted for this option" : "Du stemte på dette alternativet",
    "End poll" : "Avslutt avstemning",
    "Change your vote" : "Endre stemmen din",
    "Results" : "Resultater",
    "Voted participants" : "Stemte deltakere",
    "Send a message to \"{roomName}\"" : "Send en melding til \"{roomName}\"",
    "Hide list of participants" : "Skjul deltakerlisten",
    "Show list of participants" : "Vis listen over deltakere",
    "Assistance requested in {roomName}" : "Anmodet om bistand i {roomName}",
    "The message was sent to \"{roomName}\"" : "Meldingen ble sendt til \"{roomName}\"",
    "Dismiss request for assistance" : "Avvis forespørsel om bistand",
    "Send message to room" : "Send melding til rom",
    "Back to main room" : "Tilbake til hovedrommet",
    "Back to your room" : "Tilbake til rommet ditt",
    "Message all rooms" : "Send melding til alle rom",
    "Start session" : "Start økten",
    "Start a call before you start a breakout room session" : "Start en samtale før du starter en grupperomøkt",
    "Stop session" : "Stopp økten",
    "The message was sent to all breakout rooms" : "Meldingen ble sendt til alle grupperom",
    "Send a message to all breakout rooms" : "Send en melding til alle grupperom",
    "Breakout rooms are not started" : "Grupperom er ikke startet",
    "Disable lobby" : "Deaktiver lobby",
    "Settings for participant \"{user}\"" : "Innstillinger for deltaker \"{user}\"",
    "Participant \"{user}\"" : "Deltaker \"{user}\"",
    "moderator" : "moderator",
    "bot" : "robot",
    "guest" : "gjest",
    "Ringing …" : "Ringer...",
    "Call rejected" : "Anrop avvist",
    "{time} talking …" : "{time} snakker...",
    "{time} talking time" : "{time} taletid",
    "Raised their hand" : "Rekte opp hånden",
    "Joined with video" : "Sluttet seg til med video",
    "Joined via phone" : "Sluttet seg til via telefon",
    "Joined with audio" : "Sluttet seg til med lyd",
    "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "Teksten må bestå av mindre tegn enn eller lik {maxLength}. Den gjeldende teksten består av {charactersCount}-tegn.",
    "Remove group and members" : "Fjern gruppe og medlemmer",
    "Remove team and members" : "Fjern lag og medlemmer",
    "Remove participant" : "Fjern deltaker",
    "Do you really want to remove group \"{displayName}\" and its members from this conversation?" : "Vil du virkelig fjerne gruppen \"{displayName}\" og medlemmene fra denne samtalen?",
    "Do you really want to remove team \"{displayName}\" and its members from this conversation?" : "Vil du virkelig fjerne laget \"{displayName}\" og medlemmene fra denne samtalen?",
    "Do you really want to remove {displayName} from this conversation?" : "Vil du virkelig fjerne {displayName} fra denne samtalen?",
    "Notification was sent to {displayName}" : "Varsel sendt til {displayName}",
    "Could not send notification to {displayName}" : "Kunne ikke sende invitasjon til {displayName}",
    "Permissions granted to {displayName}" : "Rettigheter gitt til {displayName}",
    "Could not modify permissions for {displayName}" : "Kan ikke endre rettigheter for {displayName}",
    "Permissions removed for {displayName}" : "Rettigheter fjernet for {displayName}",
    "Permissions set to default for {displayName}" : "Rettigheter satt til standard for {displayName}",
    "Phone number could not be hung up" : "Telefonnummeret kunne ikke legges på",
    "Phone number could not be put on hold" : "Telefonnummeret kunne ikke settes på vent",
    "Phone number could not be muted" : "Telefonnummeret kunne ikke dempes",
    "Phone number could not be unmuted" : "Telefonnummeret kunne ikke slå på lyden",
    "DTMF message could not be sent" : "DTMF-melding kunne ikke sendes",
    "Phone number copied to clipboard" : "Telefonnummer kopiert til utklippstavlen",
    "Phone number could not be copied" : "Telefonnummer kunne ikke kopieres",
    "in the lobby" : "i lobbyen",
    "Dial out phone" : "Ring ut telefonen",
    "Hang up phone" : "Legg på telefonen",
    "Move back to lobby" : "Gå tilbake til lobbyen",
    "Move to conversation" : "Gå til samtale",
    "Dial-in PIN" : "Ring-inn PIN-kode",
    "Demote from moderator" : "Fjern moderatorstatus",
    "Promote to moderator" : "Gi moderatorstatus",
    "Resend invitation" : "Send invitasjon på nytt",
    "Send call notification" : "Send anropsvarsel",
    "Dial out phone number" : "Ring ut telefonnummer",
    "Resume call for phone number" : "Gjenoppta anrop for telefonnummer",
    "Put phone number on hold" : "Sett telefonnummeret på vent",
    "Unmute phone number" : "Oppheve demping av telefonnummer",
    "Mute phone number" : "Demp telefonnummer",
    "Copy phone number" : "Kopier telefonnummer",
    "Reset custom permissions" : "Tilbakestill egendefinerte rettigheter",
    "Grant all permissions" : "Gi alle rettigheter",
    "Remove all permissions" : "Fjern alle rettigheter",
    "Also ban from this conversation" : "Også utesteng fra denne samtalen",
    "Internal note (reason to ban)" : "Intern merknad (grunn til å utestenge)",
    "Remove" : "Fjern",
    "Permissions modified for {displayName}" : "Rettigheter endret for {displayName}",
    "Add users, groups or teams" : "Legg til brukere, grupper eller lag",
    "Add users or groups" : "Legg til bruker eller gruppe",
    "Add users or teams" : "Legg til brukere eller lag",
    "Add users" : "Legg til brukere",
    "Add groups or teams" : "Legg til brukere eller lag",
    "Add groups" : "Legg til grupper",
    "Add teams" : "Legg til lag",
    "Add other sources" : "Legg til andre kilder",
    "Add emails" : "Legg til e-post",
    "Integrations" : "Integreringer",
    "Add federated users" : "Legg til forente brukere",
    "Searching …" : "Søker ...",
    "Search for more users" : "Søk etter flere brukere",
    "You can search or add participants via name, email, or Federated Cloud ID" : "Du kan søke etter eller legge til deltakere via navn, e-post eller Federated Cloud ID",
    "Search or add participants" : "Finn eller legg til deltakere",
    "Invitation was sent to {actorId}" : "Invitasjon sendt til {actorId}",
    "An error occurred while adding the participants" : "Det oppsto en feil. Kan ikke legge til deltakerne",
    "Participants" : "Deltakere",
    "Participants ({count})" : "Deltakere ({count})",
    "Open chat" : "Åpne Chat",
    "You have new unread messages in the chat." : "Du har nye uleste meldinger i chatten.",
    "You have been mentioned in the chat." : "Du har blitt nevnt i chatten.",
    "Chat" : "Chat",
    "Details" : "Detaljer",
    "Shared items" : "Delte elementer",
    "Until" : "Til",
    "No results found" : "Ingen resultater funnet",
    "Load more results" : "Hent flere resultat",
    "Projects" : "Prosjekter",
    "No shared items" : "Ingen delte elementer",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "Kobling til en samtale",
    "No open conversations found" : "Ingen åpne samtaler funnet",
    "Either there are no open conversations or you joined all of them." : "Enten er det ingen åpne samtaler, eller så ble du med i dem alle.",
    "Check spelling or use complete words." : "Kontroller stavemåten eller bruk fullstendige ord.",
    "Search conversations or users" : "Søk etter samtaler eller brukere",
    "Select conversation" : "Velg samtale",
    "Number length is not valid" : "Tall-lengden er ikke gyldig",
    "Region code is not valid" : "Regionskoden er ikke gyldig",
    "Number length is too short" : "Tall-lengen er for kort",
    "Number length is too long" : "Tall-lengen er for lang",
    "Number is not valid" : "Nummer er ikke gyldig",
    "Phone numbers" : "Telefonnumre",
    "Display name: {name}" : "Visningsnavn: {name}",
    "Edit display name" : "Rediger visningsnavn",
    "Save name" : "Lagre navn",
    "Error while saving sounds setting" : "Feil under lagring av lydinnstilling",
    "Play sounds when participants join or leave a call" : "Spille av lyder når deltakere blir med i eller forlater en samtale",
    "Notification settings" : "Innstillinger for notifiseringer",
    "Default language" : "Standard språk",
    "Select location for attachments" : "Velg plassering for vedlegg",
    "Error while setting attachment folder" : "Feil under angivelse av vedleggsmappe",
    "Error while setting read status privacy" : "Feil under angivelse av personvern for lesestatus",
    "Error while setting typing status privacy" : "Feil under angivelse av personvern for skrivestatus",
    "Privacy" : "Personvern",
    "Attachments folder" : "Vedleggsmappe",
    "Toggle full screen" : "Veksle fullskjerm",
    "Search" : "Søk",
    "Focus the chat input" : "Fokuser chat-inndataene",
    "Unfocus the chat input to use shortcuts" : "Fjern fokuseringen på chat-inndataene for å bruke snarveier",
    "Edit your last message" : "Rediger din seneste melding",
    "Shortcuts while in a call" : "Snarveier i en samtale",
    "Camera on and off" : "Kamera på og av",
    "Microphone on and off" : "Mikrofon på og av",
    "Raise or lower hand" : "Hev eller senk hånden",
    "Push to talk or push to mute" : "Trykk for å snakke eller trykk for å dempe",
    "Start call silently" : "Start stille anrop",
    "Start call" : "Start samtale",
    "End call" : "Avslutt samtale",
    "You will be able to join the call only after a moderator starts it." : "Du vil bare kunne bli med i samtalen etter at en moderator har startet den.",
    "End call for everyone" : "Avslutt samtale for alle",
    "Starting the recording" : "Starter opptaket",
    "Recording" : "Innspilling",
    "The call has been running for one hour." : "Samtalen har pågått i én time.",
    "Cancel recording start" : "Avbryt opptaksstart",
    "Stop recording" : "Stopp opptak",
    "Raise hand" : "Løft hånden",
    "Raise hand (R)" : "Rekk opp hånden (R)",
    "Lower hand" : "Senk hånden",
    "Lower hand (R)" : "Send hånden (R)",
    "Send a reaction" : "Send en reaksjon",
    "React with {reaction}" : "Reager med {reaction}",
    "All tasks done!" : "Alle oppgaver fullført!",
    "_{done} of %n task_::_{done} of %n tasks_" : ["{done} av %n oppgave","{done} av %n oppgaver"],
    "_%n participant in call_::_%n participants in call_" : ["%n deltaker i samtale","%n deltakere i samtale"],
    "You are not allowed to enable screensharing" : "Du har ikke lov til å aktivere skjermdeling",
    "No screensharing" : "Ingen skjermdeling",
    "Screensharing options" : "Skjermdelingsvalg",
    "Enable screensharing" : "Skru på skjermdeling",
    "Bad sent video and screen quality." : "Dårlig sendt video- og skjermkvalitet.",
    "Bad sent screen quality." : "Dårlig sendt skjermkvalitet.",
    "Bad sent video quality." : "Dårlig sendt videokvalitet.",
    "Bad sent audio, video and screen quality." : "Dårlig sendt lyd-, video- og skjermkvalitet.",
    "Bad sent audio and screen quality." : "Dårlig sendt lyd- og skjermkvalitet.",
    "Bad sent audio and video quality." : "Dårlig sendt lyd- og videokvalitet.",
    "Bad sent audio quality." : "Dårlig sendt lydkvalitet.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "Internett-tilkoblingen eller datamaskinen er opptatt, og andre deltakere kan kanskje ikke se skjermen din. For å forbedre situasjonen, prøv å deaktivere bakgrunnsuskarphet eller videoen din mens du deler skjermen.",
    "Disable background blur" : "Deaktiver bakgrunnsuskarphet",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "Internett-tilkoblingen eller datamaskinen er opptatt, og andre deltakere kan kanskje ikke se skjermen din. For å forbedre situasjonen, prøv å deaktivere videoen din mens du gjør en skjermdeling.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Internett-tilkoblingen eller datamaskinen er opptatt, og andre deltakere kan kanskje ikke se skjermen din.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "Internett-tilkoblingen eller datamaskinen din er opptatt, og andre deltakere kan kanskje ikke se deg.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "Internett-tilkoblingen eller datamaskinen din er opptatt, og andre deltakere kan kanskje ikke forstå og se deg. For å forbedre situasjonen, prøv å deaktivere bakgrunnsuskarphet eller videoen din mens du gjør en skjermdeling.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Internett-tilkoblingen eller datamaskinen din er opptatt, og andre deltakere kan kanskje ikke forstå og se deg. For å forbedre situasjonen, prøv å deaktivere videoen din mens du gjør en skjermdeling.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "Internett-tilkoblingen eller datamaskinen din er opptatt, og andre deltakere kan kanskje ikke forstå deg og se skjermen din. For å forbedre situasjonen, prøv å deaktivere skjermdelingen.",
    "Disable screenshare" : "Deaktiver skjermdeling",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "Internett-tilkoblingen eller datamaskinen din er opptatt, og andre deltakere kan kanskje ikke forstå og se deg. For å forbedre situasjonen, prøv å deaktivere bakgrunnsuskarphet eller videoen din.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Internett-tilkoblingen eller datamaskinen din er opptatt, og andre deltakere kan kanskje ikke forstå og se deg. For å forbedre situasjonen, prøv å deaktivere videoen din.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Internett-tilkoblingen eller datamaskinen din er opptatt, og andre deltakere kan kanskje ikke forstå deg.",
    "Screen sharing is not supported by your browser." : "Skjermdeling støttes ikke av nettleseren din.",
    "Screen sharing requires the page to be loaded through HTTPS." : "Skjermdeling krever at siden er innlastet med HTTPS.",
    "Screensharing requires the page to be loaded through HTTPS." : "Skjermdeling krever at siden er innlastet med HTTPS.",
    "An error occurred while starting screensharing." : "En feil inntraff under oppstart av skjermdeling.",
    "Show your screen" : "Vis din skjerm",
    "Stop screensharing" : "Stopp skjermdeling",
    "Mute others" : "Demp andre",
    "Start recording" : "Start opptak",
    "Set up breakout rooms" : "Sett opp grupperom",
    "Open Calendar" : "Åpne Kalender",
    "Remove participant {name}" : "Fjern deltaker {name}",
    "Keep" : "Behold",
    "Open dialpad" : "Åpne numerisk tastatur",
    "Select a region" : "Velg region",
    "Search …" : "Søk...",
    "Message without mention" : "Melding uten å nevne",
    "Mention myself" : "Nevn meg selv",
    "Mention everyone" : "Nevn alle",
    "Select a conversation" : "Velg en samtale",
    "Select a mode" : "Velg en modus",
    "You do not have permissions to access this conversation." : "Du har ikke tillatelse til å få tilgang til denne samtalen.",
    "Join a different conversation or start a new one." : "Bli med i en annen samtale eller start en ny.",
    "The conversation does not exist" : "Samtalen finnes ikke",
    "Join a conversation or start a new one!" : "Bli med i en samtale eller start en ny!",
    "Creating and joining a conversation with \"{userid}\"" : "Opprette og bli med i en samtale med \"{userid}\"",
    "Join a conversation or start a new one" : "Ta del i en samtale eller start en ny",
    "Error while joining the conversation" : "Feil under å bli med i samtalen",
    "Nextcloud URL" : "Nextcloud URL",
    "Nextcloud user" : "Nextcloud-bruker",
    "User password" : "Brukerpassord",
    "Talk conversation" : "Talk-samtale",
    "Skip TLS verification" : "Hopp over TLS-verifisering",
    "Matrix server URL" : "Matrix server URL",
    "User" : "Bruker",
    "Matrix channel" : "Matrix-kanal",
    "Mattermost server URL" : "Mattermost server URL",
    "Mattermost user" : "Mattermost-bruker",
    "Team name" : "Navn på team",
    "Channel name" : "Kanalnavn",
    "Rocket.Chat server URL" : "Rocket.Chat server URL",
    "User name or email address" : "Brukernavn eller e-postadresse",
    "Rocket.Chat channel" : "Rocket.Chat-kanal",
    "Zulip server URL" : "Zulip server URL",
    "Bot user name" : "Brukernavn for robot",
    "Bot API key" : "Robot API-nøkkel",
    "Zulip channel" : "Zulip-kanal",
    "API token" : "API-symbol",
    "Slack channel" : "Slack-kanal",
    "Server ID or name" : "Server-ID eller navn",
    "Channel" : "Kanal",
    "Login" : "Logg inn",
    "Chat ID" : "Chat-ID",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "IRC server URL (f.eks. chat.freenode.net:6667)",
    "Nickname" : "Kallenavn",
    "Connection password" : "Passord for tilkobling",
    "IRC channel" : "IRC-kanal",
    "Channel password" : "Passord for kanal",
    "NickServ nickname" : "NickServ-kallenavn",
    "NickServ password" : "NickServ-passord",
    "Use TLS" : "Bruk TLS",
    "Use SASL" : "Bruk SASL",
    "Tenant ID" : "Tenant-ID",
    "Client ID" : "Klient-ID",
    "Team ID" : "Team-ID",
    "Thread ID" : "Tråd-ID",
    "XMPP/Jabber server URL" : "XMPP/Jabber server URL",
    "MUC server URL" : "MUC server URL",
    "Jabber ID" : "Jabber ID",
    "Media" : "Media",
    "Polls" : "Avstemninger",
    "Deck cards" : "Deck-kort",
    "Voice messages" : "Talemeldinger",
    "Locations" : "Steder",
    "Call recordings" : "Samtaleopptak",
    "Audio" : "Lyd",
    "Show all media" : "Vis alle medier",
    "Show all files" : "Vis alle filer",
    "Show all polls" : "Vis alle avstemninger",
    "Show all deck cards" : "Vis alle deck-kort",
    "Show all voice messages" : "Vis alle talemeldinger",
    "Show all locations" : "Vis alle plasseringer",
    "Show all call recordings" : "Vis alle samtaleopptak",
    "Show all audio" : "Vis all lyd",
    "Show all other" : "Vi alt annet",
    "Group" : "Gruppe",
    "Team" : "Lag",
    "You reconnected to the call" : "Du koblet til samtalen på nytt",
    "{actor} reconnected to the call" : "{actor} koblet til samtalen på nytt",
    "You added {user0} and {user1}" : "Du la til {user0} og {user1}",
    "_You added {user0}, {user1} and %n more participant_::_You added {user0}, {user1} and %n more participants_" : ["Du la til {user0}, {user1} 1 %n mer deltaker","Du la til {user0}, {user1} og %n flere deltakere"],
    "An administrator added you and {user0}" : "En administrator la til deg og {user0}",
    "{actor} added you and {user0}" : "{actor} la til deg og {user0}",
    "_An administrator added you, {user0} and %n more participant_::_An administrator added you, {user0} and %n more participants_" : ["En administrator la til deg, {user0} og %n mer deltaker","En administrator la til deg, {user0} and %n flere deltakere"],
    "_{actor} added you, {user0} and %n more participant_::_{actor} added you, {user0} and %n more participants_" : ["{actor} la til deg, {user0} og %n mer deltaker","{actor} la til deg, {user0} og %n flere deltakere"],
    "An administrator added {user0} and {user1}" : "En administrator la til {user0} og {user1}",
    "{actor} added {user0} and {user1}" : "{actor} la til {user0} og {user1}",
    "_An administrator added {user0}, {user1} and %n more participant_::_An administrator added {user0}, {user1} and %n more participants_" : ["En administrator la til {user0}, {user1} og %n mer deltaker","En administrator la til {user0}, {user1} og %n flere deltakere"],
    "_{actor} added {user0}, {user1} and %n more participant_::_{actor} added {user0}, {user1} and %n more participants_" : ["{actor} la til {user0}, {user1} og %n mer deltaker","{actor} la til {user0}, {user1} og %n flere deltakere"],
    "You removed {user0} and {user1}" : "Du fjernet {user0} og {user1}",
    "_You removed {user0}, {user1} and %n more participant_::_You removed {user0}, {user1} and %n more participants_" : ["Du fjernet {user0}, {user1} og %n deltaker til","Du fjernet {user0}, {user1} og %n deltakere til"],
    "An administrator removed you and {user0}" : "En administrator fjernet deg og {user0}",
    "{actor} removed you and {user0}" : "{actor} fjernet deg og {user0}",
    "_An administrator removed you, {user0} and %n more participant_::_An administrator removed you, {user0} and %n more participants_" : ["En administrator fjernet deg, {user0} og %n deltaker til","En administrator fjernet deg, {user0} og %n deltakere til"],
    "_{actor} removed you, {user0} and %n more participant_::_{actor} removed you, {user0} and %n more participants_" : ["{actor} fjernet deg, {user0} og %n deltaker til","{actor} fjernet deg, {user0} og %n deltakere til"],
    "An administrator removed {user0} and {user1}" : "En administrator fjernet {user0} og {user1}",
    "{actor} removed {user0} and {user1}" : "{actor} fjernet {user0} og {user1}",
    "_An administrator removed {user0}, {user1} and %n more participant_::_An administrator removed {user0}, {user1} and %n more participants_" : ["En administrator fjernet {user0}, {user1} og %n deltaker til","En administrator fjernet {user0}, {user1} og %n deltakere til"],
    "_{actor} removed {user0}, {user1} and %n more participant_::_{actor} removed {user0}, {user1} and %n more participants_" : ["{actor} fjernet {user0}, {user1} og %n deltaker til","{actor} fjernet {user0}, {user1} og %n deltakere til"],
    "You and {user0} joined the call" : "Du og {user0} ble med i samtalen",
    "_You, {user0} and %n more participant joined the call_::_You, {user0} and %n more participants joined the call_" : ["Du, {user0} og %n deltaker til ble med i samtalen","Du, {user0} og %n flere deltakere ble med i samtalen"],
    "{user0} and {user1} joined the call" : "{user0} og {user1} ble med i samtalen",
    "_{user0}, {user1} and %n more participant joined the call_::_{user0}, {user1} and %n more participants joined the call_" : ["{user0}, {user1} og %n deltaker til ble med i samtalen","{user0}, {user1} og %n flere deltakere ble med i samtalen"],
    "You and {user0} left the call" : "Du og {user0} forlot samtalen",
    "_You, {user0} and %n more participant left the call_::_You, {user0} and %n more participants left the call_" : ["Du, {user0} og %n deltaker til forlot samtalen","Du, {user0} og %n flere deltakere forlot samtalen"],
    "{user0} and {user1} left the call" : "{user0} og {user1} forlot samtalen",
    "_{user0}, {user1} and %n more participant left the call_::_{user0}, {user1} and %n more participants left the call_" : ["{user0}, {user1} og %n deltaker til forlot samtalen","{user0}, {user1} og %n flere deltakere forlot samtalen"],
    "You promoted {user0} and {user1} to moderators" : "Du forfremmet {user0} og {user1} til moderatorer",
    "_You promoted {user0}, {user1} and %n more participant to moderators_::_You promoted {user0}, {user1} and %n more participants to moderators_" : ["Du forfremmet {user0}, {user1} og %n deltaker til moderatorer","Du forfremmet {user0}, {user1} og %n flere deltakere til moderatorer"],
    "An administrator promoted you and {user0} to moderators" : "En administrator forfremmet deg og {user0} til moderatorer",
    "{actor} promoted you and {user0} to moderators" : "{actor} forfremmet deg og {user0} til moderatorer",
    "_An administrator promoted you, {user0} and %n more participant to moderators_::_An administrator promoted you, {user0} and %n more participants to moderators_" : ["En administrator forfremmet deg, {user0} og %n mer deltaker til moderatorer","En administrator forfremmet deg, {user0} og %n flere deltakere til moderatorer"],
    "_{actor} promoted you, {user0} and %n more participant to moderators_::_{actor} promoted you, {user0} and %n more participants to moderators_" : ["{actor} forfremmet deg, {user0} og %n mer deltaker til moderatorer","{actor} forfremmet deg, {user0} og %n flere deltakere til moderatorer"],
    "An administrator promoted {user0} and {user1} to moderators" : "En administrator forfremmet {user0} og {user1} til moderatorer",
    "{actor} promoted {user0} and {user1} to moderators" : "{actor} forfremmet {user0} og {user1} til moderatorer",
    "_An administrator promoted {user0}, {user1} and %n more participant to moderators_::_An administrator promoted {user0}, {user1} and %n more participants to moderators_" : ["En administrator forfremmet {user0}, {user1} og %n mer deltaker til moderatorer","En administrator forfremmet {user0}, {user1} og %n flere deltakere til moderatorer"],
    "_{actor} promoted {user0}, {user1} and %n more participant to moderators_::_{actor} promoted {user0}, {user1} and %n more participants to moderators_" : ["{actor} forfremmet {user0}, {user1} og%n mer deltaker til moderatorer","{actor} forfremmet {user0}, {user1} og %n flere deltakere til moderatorer"],
    "You demoted {user0} and {user1} from moderators" : "Du nedgraderte {user0} og {user1} fra moderatorer",
    "_You demoted {user0}, {user1} and %n more participant from moderators_::_You demoted {user0}, {user1} and %n more participants from moderators_" : ["Du nedgraderte {user0}, {user1} og %n deltaker til fra moderatorer","Du nedgraderte {user0}, {user1} og %n flere deltakere fra moderatorer"],
    "An administrator demoted you and {user0} from moderators" : "En administrator nedgraderte deg og {user0} fra moderatorer",
    "{actor} demoted you and {user0} from moderators" : "{actor} nedgraderte deg og {user0} fra moderatorer",
    "_An administrator demoted you, {user0} and %n more participant from moderators_::_An administrator demoted you, {user0} and %n more participants from moderators_" : ["En administrator nedgraderte deg, {user0} og %n deltaker til fra moderatorer","En administrator nedgraderte deg, {user0} og %n flere deltakere fra moderatorer"],
    "_{actor} demoted you, {user0} and %n more participant from moderators_::_{actor} demoted you, {user0} and %n more participants from moderators_" : ["{actor} nedgraderte deg, {user0} og %n deltaker til fra moderatorer","{actor} nedgraderte deg, {user0} og %n flere deltakere fra moderatorer"],
    "An administrator demoted {user0} and {user1} from moderators" : "En administrator nedgraderte {user0} og {user1} fra moderatorer",
    "{actor} demoted {user0} and {user1} from moderators" : "{actor} nedgraderte {user0} og {user1} fra moderatorer",
    "_An administrator demoted {user0}, {user1} and %n more participant from moderators_::_An administrator demoted {user0}, {user1} and %n more participants from moderators_" : ["En administrator nedgraderte {user0}, {user1} og %n deltaker til fra moderatorer","En administrator nedgraderte {user0}, {user1} og %n flere deltakere fra moderatorer"],
    "_{actor} demoted {user0}, {user1} and %n more participant from moderators_::_{actor} demoted {user0}, {user1} and %n more participants from moderators_" : ["{actor} nedgraderte {user0}, {user1} og %n deltaker til fra moderatorer","{actor} nedgraderte {user0}, {user1} og %n flere deltakere fra moderatorer"],
    "You: {lastMessage}" : "Du: {lastMessage}",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "(edited by you)" : "(redigert av deg)",
    "(edited by a deleted user)" : "(redigert av en slettet bruker)",
    "(edited by {moderator})" : "(redigert av {moderator})",
    "The recording failed. Please contact your administrator." : "Opptaket feilet, vennligst kontakt administratoren din.",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Du prøver å bli med i en samtale mens du har en aktiv økt i et annet vindu eller en annen enhet. Dette støttes for øyeblikket ikke av Nextcloud Talk. Hva vil du gjøre?",
    "Leave this page" : "Forlate denne siden",
    "Join here" : "Bli med her",
    "Deck card has been posted to {conversation}" : "Deck-kort er lagt til {conversation}",
    "An error occurred while posting deck card to conversation" : "En feil oppstod ved å legge ut deck-kortet til samtalen",
    "Post to a conversation" : "Legg ut til en samtale",
    "Post to conversation" : "Legg ut til samtale",
    "Location has been posted to {conversation}" : "Plassering er lagt til {conversation}",
    "An error occurred while posting location to conversation" : "En feil oppstod ved å legge ut plassering til samtale",
    "Share to a conversation" : "Del til en samtale",
    "Share to conversation" : "Del til samtale",
    "In conversation" : "I samtale",
    "Search in conversation: {conversation}" : "Søk i samtale: {conversation}",
    "Your requests are throttled at the moment due to brute force protection" : "Forespørslene dine blir strupet for øyeblikket på grunn av beskyttelse mot rå makt",
    "Error while clearing conversation history" : "Feil under tømming av samtalelogg",
    "Error occurred while allowing guests" : "Det oppstod en feil under godkjenning av gjester",
    "Error occurred while disallowing guests" : "Det oppstod en feil under avvisning av gjester",
    "Error occurred when restricting the conversation to moderator" : "Det oppstod en feil da samtalen ble begrenset til moderator",
    "Error occurred when opening the conversation to everyone" : "Det oppstod en feil da samtalen ble åpnet for alle",
    "Conversation password has been saved" : "Samtale passord er lagret",
    "Conversation password has been removed" : "Samtale passord er fjernet",
    "Error occurred while saving conversation password" : "Det oppstod en feil under lagring av samtalepassord",
    "Call recording is starting." : "Samtaleopptaket starter.",
    "Call recording stopped while starting." : "Samtaleopptaket stoppet under oppstart.",
    "Call recording stopped. You will be notified once the recording is available." : "Samtaleopptak stoppet. Du vil bli varslet når opptaket er tilgjengelig.",
    "Conversation picture set" : "Samtalebilde angitt",
    "Conversation picture deleted" : "Samtalebilde slettet",
    "Could not delete the conversation picture" : "Kunne ikke slette samtalebildet",
    "Could not post message: {errorMessage}" : "Kunne ikke legge inn melding: {errorMessage}",
    "Participant is banned successfully" : "Deltaker er utestengt",
    "Error while banning the participant" : "Feil under utestenging av deltakeren",
    "An error occurred while fetching the participants" : "Det oppstod en feil under henting av deltakerne",
    "Could not send invitation to {actorId}" : "Kunne ikke sende invitasjon til {actorId}",
    "Invitations sent" : "Invitasjoner sendt",
    "Error occurred when sending invitations" : "Det oppstod en feil under sending av invitasjoner",
    "An error occurred while creating breakout rooms" : "Det oppstod en feil under oppretting av grupperom",
    "An error occurred while re-ordering the attendees" : "Det oppstod en feil under omorganisering av deltakerne",
    "An error occurred while deleting breakout rooms" : "Det oppstod en feil under sletting av grupperom",
    "An error occurred while starting breakout rooms" : "Det oppstod en feil under oppstart av grupperom",
    "An error occurred while stopping breakout rooms" : "Det oppstod en feil under stopping av grupperom",
    "An error occurred while sending a message to the breakout rooms" : "Det oppstod en feil under sending av en melding til grupperommene",
    "An error occurred while requesting assistance" : "Det oppstod en feil under forespørsel om hjelp",
    "An error occurred while resetting the request for assistance" : "Det oppstod en feil under tilbakestilling av forespørselen om hjelp",
    "An error occurred while joining breakout room" : "Det oppstod en feil under tilknytning til grupperom",
    "An error occurred while accepting an invitation" : "Det oppstod en feil under godkjennelse av invitasjonen",
    "An error occurred while rejecting an invitation" : "Det oppstod en feil under avvisning av invitasjonen",
    "{guest} (guest)" : "{guest} (gjest)",
    "An error occurred while submitting your vote" : "Det oppstod en feil under innsending av stemmen",
    "An error occurred while ending the poll" : "Det oppstod en feil under avslutning av avstemningen",
    "Poll \"{name}\" was created by {user}. Click to vote" : "Avstemning \"{name}\" ble opprettet av {user}. Klikk for å stemme.",
    "Failed to add reaction" : "Å legge til reaksjon feilet",
    "Failed to remove reaction" : "Fjerning av reaksjon feilet",
    "Error while uploading file \"{fileName}\"" : "Feil under opplasting av fil \"{fileName}\"",
    "Not enough free space to upload file \"{fileName}\"" : "Ikke nok ledig plass til å laste opp fil \"{fileName}\"",
    "You are not allowed to share files" : "Du har ikke lov til å dele filer",
    "Error while sharing file" : "Feil under deling av fil",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Nettleseren du bruker støttes ikke fullt ut av Nextcloud Talk. Bruk den nyeste versjonen av Mozilla Firefox, Microsoft Edge, Google Chrome, Opera eller Apple Safari.",
    "_%n hour_::_%n hours_" : ["%n time","%n timer"],
    "_%n day_::_%n days_" : ["%n dag","%n dager"],
    "_%n week_::_%n weeks_" : ["%n uke","%n uker"],
    "_In %n hour_::_In %n hours_" : ["Om %n time","Om %n timer"],
    "_%n minute _::_%n minutes_" : ["%n minutt","%n minutter"],
    "In {hours} and {minutes}" : "Om {hours} og {minutes}",
    "_In %n minute_::_In %n minutes_" : ["Om %n minutt","Om %n minutter"],
    "Later today – {timeLocale}" : "Senere i dag – {timeLocale}",
    "Tomorrow – {timeLocale}" : "I morgen – {timeLocale}",
    "This weekend – {timeLocale}" : "Denne helgen – {timeLocale}",
    "Next week – {timeLocale}" : "Neste uke – {timeLocale}",
    "Conversation link copied to clipboard" : "Kobling til samtale kopiert til utklippstavlen",
    "The link could not be copied" : "Koblingen kunne ikke kopieres",
    "Error while parsing a PROPFIND error" : "Feil under analyse av en PROPFIND-feil",
    "Sending signaling message has failed" : "Sending av signalmelding feilet",
    "Lost connection to signaling server. Trying to reconnect." : "Mistet forbindelsen til signalserveren. Prøver å koble til igjen.",
    "The configured signaling server needs to be updated to be compatible with this version of Talk. Please contact your administration." : "Den konfigurerte signalserveren må oppdateres for å være kompatibel med denne versjonen av Talk. Ta kontakt med administrasjonen.",
    "Please reload the page." : "Last inn siden på nytt.",
    "Do not disturb" : "Ikke forstyrr",
    "Away" : "Borte",
    "Microphone {number}" : "Mikrofon {number}",
    "Camera {number}" : "Kamera {number}",
    "Speaker {number}" : "Høyttaler {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Du ser ut til å snakke mens du er dempet, vær så snill å slå på lyden for at andre skal høre deg",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "Kunne ikke etablere en forbindelse med minst én deltaker. En TURN-server kan være nødvendig for scenariet ditt. Be administratoren om å konfigurere en etter {linkstart}denne dokumentasjonen{linkend}.",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Dette tar lengre tid enn forventet. Er medietillatelsene allerede gitt (eller avvist)? Hvis ja, vennligst start nettleseren på nytt, da lyd og video svikter.",
    "Access to microphone & camera is only possible with HTTPS" : "Tilgang til mikrofon og kamera er kun mulig via HTTPS",
    "Please move your setup to HTTPS" : "Flytt oppsettet ditt til HTTPS",
    "Access to microphone & camera was denied" : "Tilgang til mikrofon og kamera var avvist",
    "WebRTC is not supported in your browser" : "WebRTC er ikke støttet av din nettleser",
    "Please use a different browser like Firefox or Chrome" : "Bruk en annen nettleser, som Firefox eller Chrome",
    "Error while accessing microphone & camera" : "Feil med tilgang til mikrofon og kamera",
    "%s Talk on your mobile devices" : "%s Talk på dine mobile enheter",
    "Join conversations at any time, anywhere, on any device." : "Bli med i samtaler når som helst, hvor som helst, på hvilken som helst enhet.",
    "Android app" : "Android-app",
    "iOS app" : "iOS-app",
    "__language_name__" : "Norsk bokmål",
    "Call summary (%s)" : "Samtalesammendrag (%s)",
    "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "Samtalesammendragsroboten legger ut en oversiktsmelding etter samtalen som viser alle deltakerne og skisserer oppgaver",
    "Tasks" : "Oppgaver",
    "Notes" : "Notater",
    "Reports" : "Rapporter",
    "Call summary" : "Samtalesammendrag",
    "Call summary - {title}" : "Samtalesammendrag - {title}",
    "Talk to %s" : "Snakk med %s",
    "Join conversations from remote Nextcloud servers" : "Bli med i samtaler fra eksterne Nextcloud-servere",
    "Set reminder for later today" : "Sett påminnelse til senere i dag",
    "Set reminder for tomorrow" : "Sett påminnelse for i morgen",
    "Set reminder for this weekend" : "Sett påminnelse for denne helgen",
    "Set reminder for next week" : "Sett påminnelse for neste uke",
    "Open poll • You voted already" : "Åpen avstemning • Du har stemt allerede",
    "Open poll • Click to vote" : "Åpen avstemning • Klikk for å stemme",
    "Poll • Ended" : "Avstemning • Avsluttet",
    "Talk recording from {time} ({conversation})" : "Taleopptak fra {time} ({conversation})",
    "_Poll results • %n vote_::_Poll results • %n votes_" : ["Avstemningsresultater • %n stemme","Avstemningsresultater • %n stemmer"],
    "_Open poll • %n vote_::_Open poll • %n votes_" : ["Åpen avstemning • %n stemme","Åpen avstemning • %n stemmer"],
    "Submit vote" : "Send inn stemme",
    "Your privacy setting has been saved" : "Personverninnstillingen din er lagret",
    "Failed to save sounds setting" : "Kunne ikke lagre lydinnstillingen",
    "Sounds setting saved" : "Lydinnstilling lagret",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Du ble med i samtalen i et annet vindu eller på en annen enhet. Dette støttes for øyeblikket ikke av Nextcloud Talk, så denne økten ble lukket."
},
"nplurals=2; plural=(n != 1);");
